# -*- coding: utf-8 -*-

__revision__ = '$Id: PluginMovieTanukiAnime.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2005-2007 Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie,string

plugin_name         = 'Tanuki-Anime'
plugin_description  = 'Największy zbiór recenzji anime w Polsce'
plugin_url          = 'anime.tanuki.pl'
plugin_language     = _('Polish')
plugin_author       = 'Piotr Ozarowski'
plugin_author_email = '<ozarow+griffith@gmail.com>'
plugin_version      = '1.3'

class Plugin(movie.Movie):
	def __init__(self, id):
		if str(id).find('http://') != -1:
			self.movie_id = 'TA'
			self.url = str(id)
		else:
			self.movie_id = str(id)
			self.url = "http://anime.tanuki.pl/strony/anime/%s" % str(id)
		self.encode='UTF-8'
	
	def initialize(self):
		if self.movie_id == 'TA':
			self.movie_id = gutils.trim(self.page, '"><a href="/strony/anime/', '/oceny')
			self.url = "http://anime.tanuki.pl/strony/anime/%s" % self.movie_id

	def get_image(self):
		self.image_url = gutils.trim(self.page, '<img src="/screens/', '<br />')
		self.image_url = gutils.before(self.image_url, '"')
		self.image_url = "http://anime.tanuki.pl/screens/%s" % self.image_url

	def get_o_title(self):
		self.o_title = gutils.trim(self.page, '<h3 class="animename"', '</h3>')
		self.o_title = gutils.after(self.o_title, '>')

	def get_title(self):
		self.title = self.o_title

	def get_director(self):
		self.director = gutils.trim(self.page, "<th scope=\"row\">Reżyser:</th>\n\t<td>", '</td>')

	def get_plot(self):
		self.plot = gutils.trim(self.page, "<div class=\"copycat\">\n", '</div>')

	def get_year(self):
		self.year = gutils.trim(self.page,'<div class=\"sitem\">Rok wydania: <', '</a>')
		self.year = gutils.after(self.year, '>')

	def get_runtime(self):
		self.runtime = gutils.trim(self.page, "<div class=\"sitem\">Czas trwania: <b>\n\t\t", '\n</b>')
		if self.runtime.find('?') != -1:
			self.runtime = ''
		else:
			self.runtime = gutils.after(self.runtime, '×')
			self.runtime = gutils.before(self.runtime, ' min')

	def get_genre(self):
		self.genre = gutils.trim(self.page, "<div class=\"sitem\">Gatunki:\n\t\t", '</div>')
		self.genre = string.replace(self.genre, "\t\t", ' ')

	def get_cast(self):
		self.cast = ''

	def get_classification(self):
		self.classification = ''

	def get_studio(self):
		self.studio = gutils.trim(self.page, "<th scope=\"row\">Studio:</th>\n\t<td>\n", "\t</td>")

	def get_o_site(self):
		self.o_site = ''

	def get_site(self):
		self.site = self.url

	def get_trailer(self):
		self.trailer = ''

	def get_country(self):
		self.country = ''

	def get_rating(self):
		self.rating = gutils.trim(self.page, ' alt="Ocena ', '/10')

	def get_notes(self):
		self.notes = "Czas trwania: " + gutils.trim(self.page,"<div class=\"sitem\">Czas trwania: <b>\n\t\t","\n</b>") + '\n'

		t = self.page.find("<tr><th scope=\"row\">Autor:</th>")
		if t != -1:
			self.notes += "Autor: %s\n" % gutils.trim(self.page[t:], "<td>\n", "\t</td>")

		t = self.page.find("<th scope=\"row\">Projekt:</th>")
		if t != -1:
			self.notes += "Projekt: %s\n" % gutils.trim(self.page[t:], "<td>\n", "\t</td>")

		t = self.page.find("<tr><th scope=\"row\">Scenariusz:</th>")
		if t != -1:
			self.notes += "Scenariusz: %s\n" % gutils.trim(self.page[t:], "<td>\n", "\t</td>")

		t = self.page.find("<th scope=\"row\">Muzyka:</th>")
		if t != -1:
			self.notes += "Muzyka: %s\n" % gutils.trim(self.page[t:], "<td>\n", "\t</td>")

		self.notes += "\n%s"  % gutils.trim(self.page,"<p class=\"dwazdania\">\n\t\t", "\n</p>")

class SearchPlugin(movie.SearchMovie):
	def __init__(self):
		self.encode='UTF-8'
		self.original_url_search   = 'http://anime.tanuki.pl/strony/anime/lista/title/1/?&title='
		self.translated_url_search = 'http://anime.tanuki.pl/strony/anime/lista/title/1/?&title='

	def search(self,parent_window):
		self.open_search(parent_window)
		tmp = string.find(self.page, "<table class=\"animelist strippedlist\"")
		if tmp == -1:	# only one match!
			self.page = ''
		else:		# multiple matches
			self.page = gutils.trim(self.page,"<table class=\"animelist strippedlist\"", "</tbody>");
			self.page = gutils.after(self.page, "<tbody>")
		return self.page

	def get_searches(self):
		if self.page == '':	# immediately redirection to movie page
			self.number_results = 1
			self.ids.append(self.url)
			self.titles.append(gutils.convert_entities(self.title))
		else:			# multiple matches
			elements = string.split(self.page,"<tr")
			self.number_results = elements[-1]
			if (elements[0]<>''):
				for element in elements:
					self.ids.append(gutils.trim(element, 'href="/strony/anime/', '" >'))
					element = gutils.after(element," >\n\t")
					element = element.replace("</a>\n\t</td>\n", " (")
					element = element.replace("\t<td>", "")
					element = element.replace("</td>\n", "; ")
					element = element.replace("</tr>", "")
					element = element[:len(element)-3] + ')'
					self.titles.append(element)
			else:
				self.number_results = 0



# -*- coding: UTF-8 -*-

__revision__ = '$Id: PluginMovie7arte.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2005-2006 Vasco Nunes, Piotr Ozarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie
import string

plugin_name = "7arte"
plugin_description = "O cinema em Portugal"
plugin_url = "7arte.net"
plugin_language = _("Portuguese")
plugin_author = "Vasco Nunes"
plugin_author_email = "<vasco.m.nunes@gmail.com>"
plugin_version = "0.6"

class Plugin(movie.Movie):
	"""A movie plugin object"""
	def __init__(self, id):
		self.encode='iso-8859-1'
		self.movie_id = id
		self.url = "http://7arte.net/cgi-bin/filme.pl?codigo=" + str(self.movie_id)

	def get_image(self):
		"""Finds the film's poster image"""
		self.image_url = "http://7arte.net/imagens/filmes/" + str(self.movie_id) + ".jpg"

	def get_o_title(self):
		"""Finds the film's original title"""
		self.o_title = string.capwords(gutils.trim(self.page, "</B></FONT><BR>", "<BR>"))

	def get_title(self):
		"""Finds the film's local title.
		Probably the original title translation"""
		self.title = string.capwords(gutils.trim(self.page, "<FONT SIZE=+1><B>", "</B>"))

	def get_director(self):
		"""Finds the film's director"""
		self.director = gutils.trim(self.page, "</B> <FONT SIze=-1>", "</FONT><TABLE><TR>")
		self.director = gutils.strip_tags(self.director)

	def get_plot(self):
		"""Finds the film's plot"""
		self.plot = gutils.trim(self.page, "<B>Sinopse:</B><BR>", "<Font Size=-2>[ www.7arte.net ]</font></FONT></P>")

	def get_year(self):
		"""Finds the film's year"""
		self.year = gutils.trim(self.page, "<B>Ano:</B> <FONT SIze=-1>", "</FONT>")

	def get_runtime(self):
		"""Finds the film's running time"""
		self.runtime = gutils.trim(self.page, "<B>Dura", " minutos")
		self.runtime = gutils.after(self.runtime, "-1>")

	def get_genre(self):
		"""Finds the film's genre"""
		self.genre = gutils.trim(self.page, "nero:</B> <FONT SIze=-1>", "</FONT><BR>")

	def get_cast(self):
		self.cast = gutils.trim(self.page, "<B>Actores:</B>", "</FONT></TD>")
		self.cast = string.replace(self.cast, "<B>»</B> ", "")

	def get_classification(self):
		"""Find the film's classification"""
		self.classification = gutils.trim(self.page, "<B>Idade:</B> <FONT SIze=-1>", "</FONT>")

	def get_studio(self):
		"""Find the studio"""
		self.studio = gutils.trim(self.page, "<B>Distribuidora:</B> <FONT SIze=-1>", "</FONT>")

	def get_o_site(self):
		"""Find the film's oficial site"""
		self.o_site = gutils.trim(self.page, \
			"<A HREF='", \
			"' TARGET=_blank><IMG SRC='/imagens/bf_siteoficial.gif'")

	def get_site(self):
		"""Find the film's imdb details page"""
		self.site = gutils.trim(self.page, \
			"/imagens/bf_siteoficial.gif' WIDTH=89 HEIGHT=18 BORDER=0 ALT=''>", \
			"' TARGET=_blank><IMG SRC='/imagens/bf_imdb.gif'")
		self.site = gutils.after(self.site, "<A HREF='")
		self.site = string.replace(self.site, "'", "")

	def get_trailer(self):
		"""Find the film's trailer page or location"""
		self.trailer = gutils.trim(self.page, \
			"/imagens/bf_imdb.gif' WIDTH=89 HEIGHT=18 BORDER=0 ALT=''>", \
			"' TARGET=_blank><IMG SRC='/imagens/bf_trailer.gif'")
		self.trailer = gutils.after(self.trailer, "<A HREF='")

	def get_country(self):
		"""Find the film's country"""
		self.country = gutils.trim(self.page, "s de Origem:</B> <FONT SIze=-1>", "</FONT><BR>")

	def get_rating(self):
		"""Find the film's rating. From 0 to 10.
		Convert if needed when assigning."""
		tmp_rating = gutils.trim(self.page, "ticas por:</B></Center>", "c_critica.pl?id=")
		if tmp_rating:
			self.rating = str(float(string.count(tmp_rating, 'estrela.gif'))*2)

class SearchPlugin(movie.SearchMovie):
	"""A movie search object"""
	def __init__(self):
		self.original_url_search = "http://7arte.net/cgi-bin/arq_search_orig.pl?proc="
		self.translated_url_search = "http://7arte.net/cgi-bin/arq_search.pl?proc="
		self.encode='iso-8859-1'

	def search(self, parent_window):
		"""Perform the web search"""
		self.open_search(parent_window)
		self.sub_search()
		return self.page

	def sub_search(self):
		"""Isolating just a portion (with the data we want) of the results"""
		self.page = gutils.trim(self.page, \
			"Resultados Encontrados</I></B></FONT>", "</DIR></FONT>")

	def get_searches(self):
		"""Try to find both id and film title for each search result"""
		elements = string.split(self.page, "</A><BR>")
		self.number_results = elements[-1]

		if (len(elements[0])):
			for element in elements:
				self.ids.append(gutils.trim(element, "codigo=", "')"))
				self.titles.append(gutils.convert_entities \
					(gutils.trim(element, "')\">", " )")) + " )")
		else:
			self.number_results = 0




# -*- coding: utf-8 -*-

__revision__ = '$Id: PluginMovieFilmweb.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2005-2007 Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils, movie
import re,string

plugin_name		= 'Filmweb'
plugin_description	= 'Web pełen filmów'
plugin_url		= 'www.filmweb.pl'
plugin_language		= _('Polish')
plugin_author		= 'Piotr Ożarowski'
plugin_author_email	= '<ozarow+griffith@gmail.com>'
plugin_version		= '1.12'

class Plugin(movie.Movie):
	TRAILER_PATTERN     = re.compile("""<a class=["']notSelected["'].*?href=["'](.*?)["']>zwiastuny</a>\s*\[\d+\]\s*&raquo;""")
	DIRECTOR_PATTERN    = re.compile('yseria\s+(.*)\s+scenariusz', re.MULTILINE)
	O_TITLE_AKA_PATTERN = re.compile('\(AKA\s+(.*?)\)')

	def __init__(self, id):
		self.movie_id = 'filmweb'
		self.url      = str(id)
		self.encode   = 'utf-8'

	def get_image(self):
		if string.find(self.page,'<div class="film-poster">') > -1:
			self.image_url = gutils.trim(self.page, 'rel="artshow" href="', '">')
		else:
			self.image_url = ''

	def get_o_title(self):
		self.o_title = gutils.trim(self.page, '<title>', '</title>')
		if string.find(self.o_title, '/') > -1:
			self.o_title = gutils.trim(self.o_title, '/', '(')
		if string.find(self.o_title, '(') > -1:
			self.o_title = gutils.before(self.o_title, '(')

	def get_title(self):
		self.title = gutils.trim(self.page, '<title>', '</title>')
		if string.find(self.title, '(') > -1:
			self.title = gutils.before(self.title, '(')
		if string.find(self.title, '/') > -1:
			self.title = gutils.before(self.title, '/')
			
	def get_director(self):
		director = self.DIRECTOR_PATTERN.findall(self.page)
		if len(director)>0:
			self.director = director[0]
			self.director = string.replace(self.director, "\t",'')
			self.director = re.sub('\s+', ' ', self.director)
			self.director = string.replace(self.director, ",",", ")
			self.director = string.replace(self.director, "  "," ")
			self.director = string.replace(self.director, " ,  ",", ")
			self.director = string.replace(self.director, ",  (wi\xeacej&#160;...)",'')

	def get_plot(self):
		self.plot = gutils.trim(self.page,'<h2 id="o-filmie-header" class="replace">','</div>')
		self.plot = gutils.after(self.plot, '<p>')
		url = gutils.trim(self.plot,"\t...","</a>")
		url = gutils.trim(url, 'href="','"')
		self.plot = gutils.strip_tags(self.plot)
		if url != '':
			plot_page = self.open_page(url=url)
			self.plot = gutils.trim(plot_page, '<div class="filmContent">', '</ul>')
			self.plot = gutils.after(self.plot, 'zgłoś poprawkę')

	def get_year(self):
		self.year = gutils.trim(self.page, '<span class="year">', '</a>')

	def get_runtime(self):
		self.runtime = gutils.trim(self.page,"\tczas trwania: ","\n")

	def get_genre(self):
		self.genre = gutils.trim(self.page,"\tgatunek:", '</p>')
		self.genre = string.replace(self.genre, "\t",'')
		self.genre = string.replace(self.genre, "\n",'')

	def get_cast(self):
		self.cast = gutils.trim(self.page, '<td class="film-actor">',"zobacz więcej")
		self.cast = string.replace(self.cast, chr(13),"")
		self.cast = string.replace(self.cast, chr(10),"")
#		self.cast = string.replace(self.cast, "\n","")
		self.cast = string.replace(self.cast, "\t",'')
		self.cast = string.replace(self.cast, "  ",'')
		self.cast = string.replace(self.cast, '<td class="film-protagonist">', _(" as "))
		self.cast = string.replace(self.cast, '</tr>',"\n")
		self.cast = gutils.strip_tags(self.cast)

	def get_classification(self):
		self.classification = gutils.trim(self.page,"\tod lat: ","\t")
		self.classification = string.replace(self.classification, "\t",'')
		self.classification = string.replace(self.classification, "\n",'')

	def get_studio(self):
		self.studio = ''

	def get_o_site(self):
		self.o_site = ''

	def get_site(self):
		self.site = self.url

	def get_trailer(self):
		trailer = self.TRAILER_PATTERN.findall(self.page)
		if trailer:
			self.trailer = trailer[0]

	def get_country(self):
		self.country = gutils.trim(self.page,"\tprodukcja:", '</strong>')
		self.country = string.replace(self.country, "\t",'')

	def get_rating(self):
		self.rating = gutils.trim(self.page, '\t<span><strong class="value">', '</strong>')
		if self.rating != '':
			self.rating = string.replace(self.rating, ',', '.')
			self.rating = str( float(string.strip(self.rating)) )

	def get_notes(self):
		self.notes = ''

class SearchPlugin(movie.SearchMovie):
	def __init__(self):
		self.encode='utf-8'
		self.original_url_search   = "http://www.filmweb.pl/szukaj?c=film&q="
		self.translated_url_search = "http://www.filmweb.pl/szukaj?c=film&q="

	def search(self,parent_window):
		self.open_search(parent_window)
		pos = string.find(self.page, 'Znaleziono <b>')
		if pos == -1:	# movie page
			self.page = None
		else:		# search results
			items = gutils.trim(self.page[pos:], '<b>', '</b>')
			if items == '0':
				self.page = False
			else:
				self.page = gutils.before(self.page[pos:], 'id="sitemap"')
				self.page = gutils.after(self.page, '<li ')
		return self.page

	def get_searches(self):
		if self.page is None:	# movie page
			self.number_results = 1
			self.ids.append(self.url)
			self.titles.append(gutils.convert_entities(self.title))
		elif self.page is False: # no movie found
			self.number_results = 0
		else:			# multiple matches
			elements = string.split(self.page, '<li ')
			self.number_results = elements[-1]
			if (elements[0]<>''):
				for element in elements:
					element = gutils.after(element, '<a class="searchResultTitle" href="')
					self.ids.append(gutils.before(element, '">'))
					element = gutils.trim(element, '">', '</a>')
					element = gutils.convert_entities(element)
					element = gutils.strip_tags(element)
					self.titles.append(element)
			else:
				self.number_results = 0



# -*- coding: UTF-8 -*-

__revision__ = '$Id: gdebug.py 1029 2008-11-10 16:58:54Z mikej06 $'

# Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gtk
import pygtk

class GriffithDebug:
	debug_mode = None
	
	def __init__(self, mode=False):
		self.debugWindow = None
		self.set_debug(mode)

	def set_debug(self, mode=True):
		self.debug_mode = mode
		self.check_for_window()
		if not (self.debugWindow is None or self.debugWindow == False):
			if mode:
				self.debugWindow.show()
			else:
				self.debugWindow.hide()

	def check_for_window(self):
		# on windows systems all output to stdout goes to a black hole
		# if py2exe is used.
		# so we use a normal window and redirect output from sys.stderr
		# and sys.stdout. it is easier to use for windows users.
		try:
			if self.debug_mode and self.debugWindow is None:
				import gutils, sys
				if gutils.is_windows_system():
					self.debugWindow = DebugWindow(None)
					sys.stderr = sys.stdout = DebugWindowRedirector(self.debugWindow)
				else:
					self.debugWindow = False
		except:
			pass

	def show(self, txt):
		if self.debug_mode:
			print txt.encode('utf8')

#
# used on windows systems
# shows a windows with a text view which displays the
# debug output provided by DebugWindowRedirector
#
class DebugWindow:
	def __init__(self, window):
		self.dialog = gtk.Dialog('Debug Window', window, gtk.DIALOG_MODAL, ())
		self.dialog.set_destroy_with_parent(True)
		self.dialog.set_transient_for(window)
		self.dialog.set_modal(False)
		self.textview = gtk.TextView()
		self.textview.set_editable(False)
		self.textview.set_wrap_mode(gtk.WRAP_WORD_CHAR)
		self.textview.set_scroll_adjustments(gtk.Adjustment(1.0, 1.0, 100.0, 1.0, 10.0, 10.0), gtk.Adjustment(1.0, 1.0, 100.0, 1.0, 10.0, 10.0))
		self.scrolledwindow = gtk.ScrolledWindow(None, None)
		self.scrolledwindow.add(self.textview)
		self.dialog.vbox.pack_start(self.scrolledwindow)
		self.dialog.set_default_size(640, 480)
	def show(self):
		self.dialog.show_all()
	def hide(self):
		self.dialog.hide_all()
	def close(self):
		self.dialog.destroy()
	def add(self, txt):
		if txt is not None:
			buffer = self.textview.get_buffer()
			buffer.insert(buffer.get_end_iter(), txt, -1)

#
# used on windows system
# redirects sys.stderr and sys.stdout to a debug window and a file
# 'griffith_debug.txt' in the home directory (My documents)
#
class DebugWindowRedirector(object):
	softspace = 0
	def __init__(self, debugWindow):
		self.debugWindow = debugWindow
		#
		# redirected output to a debug file in the home directory because
		# users with restricted system rights can't write to the installation directory
		# which is the default if py2exe is used
		#
		import winshell, os
		from win32com.shell import shellcon, shell
		from locale import getdefaultlocale
		defaultLang, defaultEnc = getdefaultlocale()
		if defaultEnc is None:
			defaultEnc = 'UTF-8'
		self.debugFileName = os.path.join(shell.SHGetFolderPath(0, shellcon.CSIDL_PERSONAL, 0, 0), 'griffith_debug.txt').decode(defaultEnc)
		try:
			f = open(self.debugFileName, 'w')
			f.close()
		except:
			pass
	def write(self, text):
		self.debugWindow.add(text)
		try:
			f = open(self.debugFileName, 'a')
			try:
				f.write(text)
			finally:
				f.close()
		except:
			pass
	def flush(self):
		pass



# -*- coding: UTF-8 -*-

__revision__ = '$Id: gemail.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2005-2007 Vasco Nunes

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import socket
import smtplib
import gutils

socket.setdefaulttimeout(10)

def mailto(self, tls, port, server, auth, user, password, sender, to, subject, msg):
	"""
	sends an email
	"""
	try:
		session = smtplib.SMTP(server, port)
		session.set_debuglevel(1)
	except socket.timeout:
		gutils.error(self, _("Connection timed out"), \
			self.widgets['window'])
		return()
	if tls == True:
		session.ehlo()
		session.starttls()
		session.ehlo()
	if auth:
		try:
			session.login(user, password)
		except:
			gutils.error(self, _("Error sending e-mail: %s")%_("login failure"), \
				self.widgets['window'])
			return
	headers = "From: %s\r\nTo: %s\r\nSubject: %s\r\n\r\n" \
		% (sender, to, subject)
	try:
		smtpresult = session.sendmail(sender, to, headers+msg)
		gutils.info(self, _("E-mail sent sucessfuly"), self.widgets['window'])
		return
	except:
		gutils.error(self, _("Error sending e-mail: %s")%"", self.widgets['window'])
		
	session.quit()

def send_email(self):
	if len(self.person_email):
		if self.config.get('use_auth', False, section='mail') == True:
			use_auth = 1
		else:
			use_auth = 0
		try:
			mailto(self, self.config.get('mail_use_tls', False, section='mail'), \
				self.config.get('mail_smtp_port', '25', section='mail'), \
				self.config.get('smtp_server', 'localhost', section='mail'), \
				use_auth, self.config.get('username', '', section='mail'), \
				self.config.get('password', '', section='mail'), \
				self.config.get('email', 'griffith', section='mail'), self.person_email, \
				_("Movie loan reminder"), _("Hi, %s!\n\nJust to remind you " + \
				"that I'm really needing the following movie I have loaned to you " + \
				"recently:\n\n%s (%s)\n\nLoaned on %s") \
				%(self.person_name, self.widgets['movie']['o_title'].get_text().decode('utf-8'), \
				self.widgets['movie']['title'].get_text().decode('utf-8'), self.loan_date[:10]))
		except:
			gutils.error(self, _("Mail could not be sent. Please check e-mail preferences."), self.widgets['window'])
	else:
		gutils.info(self, _("This person has no e-mail address defined."), \
			self.widgets['window'])



# -*- coding: UTF-8 -*-

__revision__ = '$Id: PluginMovieIMDB.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils, movie
import string, re

plugin_name		= 'IMDb'
plugin_description	= 'Internet Movie Database'
plugin_url		= 'www.imdb.com'
plugin_language		= _('English')
plugin_author		= 'Vasco Nunes, Piotr Ożarowski'
plugin_author_email	= 'griffith-private@lists.berlios.de'
plugin_version		= '1.5'

class Plugin(movie.Movie):
	def __init__(self, id):
		self.encode = 'utf-8'
		self.movie_id = id
		self.url = "http://imdb.com/title/tt%s" % str(self.movie_id)

	def initialize(self):
		self.cast_page = self.open_page(url=self.url + '/fullcredits')
		self.plot_page = self.open_page(url=self.url + '/plotsummary')

	def get_image(self):
		tmp = string.find(self.page, 'a name="poster"')
		if tmp == -1:		# poster not available
			self.image_url = ''
		else:
			self.image_url = gutils.trim(self.page[tmp:], 'src="', '"')

	def get_o_title(self):
		self.o_title = self.regextrim(self.page, '<h1>', '([ ]|[&][#][0-9]+[;])<span')
		if self.o_title == '':
			self.o_title = re.sub('[(].*', '', gutils.trim(self.page, '<title>', '</title>'))

	def get_title(self):	# same as get_o_title()
		self.title = self.regextrim(self.page, '<h1>', '([ ]|[&][#][0-9]+[;])<span')
		if self.title == '':
			self.title = re.sub('[(].*', '', gutils.trim(self.page, '<title>', '</title>'))

	def get_director(self):
		pattern = re.compile('<h5>Director[s]*?:</h5>[\n\s\r]*(.*?)(?:<br/>)?(?:<a[^>]+>more</a>)?[\n]*</div')
		result = pattern.search(self.page)
		if result:
			self.director = result.groups()[0]
			self.director = self.director.replace('<br/>', ', ')

	def get_plot(self):
		self.plot = gutils.trim(self.page, '<h5>Plot Outline:</h5>', '</div>')
		self.plot = self.__before_more(self.plot)
		elements = string.split(self.plot_page, '<p class="plotpar">')
		if len(elements) > 1:
			self.plot = self.plot + '\n\n'
			elements[0] = ''
			for element in elements:
				if element <> '':
					self.plot = self.plot + gutils.strip_tags(gutils.before(element, '</a>')) + '\n'

	def get_year(self):
		self.year = gutils.trim(self.page, '<a href="/Sections/Years/', '</a>')
		self.year = gutils.after(self.year, '">')

	def get_runtime(self):
		self.runtime = gutils.trim(self.page, '<h5>Runtime:</h5>', ' min')

	def get_genre(self):
		self.genre = gutils.trim(self.page, '<h5>Genre:</h5>', '</div>')
		self.genre = self.__before_more(self.genre)

	def get_cast(self):
		self.cast = ''
		self.cast = gutils.trim(self.cast_page, '<table class="cast">', '</table>')
		if self.cast == '':
			self.cast = gutils.trim(self.page, '<table class="cast">', '</table>')
		self.cast = string.replace(self.cast, ' ... ', _(' as '))
		self.cast = string.replace(self.cast, '...', _(' as '))
		self.cast = string.replace(self.cast, '</tr><tr>', "\n")
		self.cast = string.replace(self.cast, '</tr><tr class="even">', "\n")
		self.cast = string.replace(self.cast, '</tr><tr class="odd">', "\n")
		self.cast = self.__before_more(self.cast)

	def get_classification(self):
		self.classification = gutils.trim(self.page, '<h5><a href="/mpaa">MPAA</a>:</h5>', '</div>')
		self.classification = gutils.trim(self.classification, 'Rated ', ' ')

	def get_studio(self):
		self.studio = gutils.trim(self.page, '<h5>Company:</h5>', '</a>')

	def get_o_site(self):
		self.o_site = ''

	def get_site(self):
		self.site = "http://www.imdb.com/title/tt%s" % self.movie_id

	def get_trailer(self):
		self.trailer = "http://www.imdb.com/title/tt%s/trailers" % self.movie_id

	def get_country(self):
		self.country = gutils.trim(self.page, '<h5>Country:</h5>', '</div>')

	def get_rating(self):
		pattern = re.compile('>([0-9]([.][0-9])*)[/][0-9][0-9]<')
		result = pattern.search(self.page)
		if result:
			self.rating = result.groups()[0]
			if self.rating:
				try:
					self.rating = float(self.rating)
				except Exception, e:
					self.rating = 0
		else:
			self.rating = 0

	def get_notes(self):
		self.notes = ''
		language = gutils.trim(self.page, '<h5>Language:</h5>', '</div>')
		language = gutils.strip_tags(language)
		language = re.sub('[\n]+', '', language)
		language = re.sub('[ ]+', ' ', language)
		language = language.rstrip()
		color = gutils.trim(self.page, '<h5>Color:</h5>', '</div>')
		color = gutils.strip_tags(color)
		color = re.sub('[\n]+', '', color)
		color = re.sub('[ ]+', ' ', color)
		color = color.rstrip()
		sound = gutils.trim(self.page, '<h5>Sound Mix:</h5>', '</div>')
		sound = gutils.strip_tags(sound)
		sound = re.sub('[\n]+', '', sound)
		sound = re.sub('[ ]+', ' ', sound)
		sound = sound.rstrip()
		tagline = gutils.trim(self.page, '<h5>Tagline:</h5>', '</div>')
		tagline = self.__before_more(tagline)
		tagline = gutils.strip_tags(tagline)
		tagline = re.sub('[\n]+', '', tagline)
		tagline = re.sub('[ ]+', ' ', tagline)
		tagline = tagline.rstrip()
		if len(language)>0:
			self.notes = "%s: %s\n" %(_('Language'), language)
		if len(sound)>0:
			self.notes += "%s: %s\n" %(gutils.strip_tags(_('<b>Audio</b>')), sound)
		if len(color)>0:
			self.notes += "%s: %s\n" %(_('Color'), color)
		if len(tagline)>0:
			self.notes += "%s: %s\n" %('Tagline', tagline)
	
	def __before_more(self, data):
		tmp = string.find(data, '>more<')
		if tmp>0:
			data = data[:tmp] + '>'
		return data

	def regextrim(self,text,key1,key2):
		obj = re.search(key1, text)
		if obj is None:
			return ''
		else:
			p1 = obj.end()
		obj = re.search(key2, text[p1:])
		if obj is None:
			return ''
		else:
			p2 = p1 + obj.start()
		return text[p1:p2]

class SearchPlugin(movie.SearchMovie):
	PATTERN = re.compile(r"""<A HREF=['"]/title/tt([0-9]+)/["']>(.*?)</LI>""")
	PATTERN2 = re.compile(r"""<a href=['"]/title/tt([0-9]+)/["']>(.*?)</td>""")

	def __init__(self):
		self.original_url_search	= 'http://www.imdb.com/List?words='
		self.translated_url_search	= 'http://www.imdb.com/find?more=tt;q='
		self.encode = 'utf-8'

	def search(self,parent_window):
		self.open_search(parent_window)
		tmp_page = gutils.trim(self.page, 'Here are the', '</TABLE>')
		if tmp_page == '':
			self.page = gutils.trim(self.page, '(Displaying', '<b>Suggestions For Improving Your Results</b>')
		else:
			self.page = tmp_page
		self.page = self.page.decode('iso-8859-1')
		return self.page

	def get_searches(self):
		elements = re.split('<LI>', self.page)
		if len(elements) < 2:
			elements = string.split(self.page, '<tr>')
			if len(elements):
				for element in elements[1:]:
					match = self.PATTERN2.findall(element)
					if len(match):
						tmp  = gutils.clean(match[0][1])
						self.ids.append(match[0][0])
						self.titles.append(tmp)
		else:
			for element in elements[1:]:
				match = self.PATTERN.findall(element)
				if len(match):
					tmp  = gutils.clean(match[0][1])
					self.ids.append(match[0][0])
					self.titles.append(tmp)



# -*- coding: UTF-8 -*-

__revision__ = '$Id: loan.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import gtk
import datetime

def loan_movie(self):
	people = self.db.Person.select(order_by='name ASC')
	model = gtk.ListStore(str)
	if len(people)>0:
		for person in people:
			model.append([person.name])
		self.widgets['movie']['loan_to'].set_model(model)
		self.widgets['movie']['loan_to'].set_text_column(0)
		self.widgets['movie']['loan_to'].set_active(0)
		self.widgets['w_loan_to'].show()
	else:
		gutils.info(self, _("No person is defined yet."), self.widgets['window'])

def cancel_loan(self):
	self.widgets['w_loan_to'].hide()

def commit_loan(self):
	person_name = gutils.on_combo_box_entry_changed(self.widgets['movie']['loan_to'])
	if person_name == '' or person_name is None:
		return False
	self.widgets['w_loan_to'].hide()

	person = self.db.Person.get_by(name=person_name)
	if person is None:
		self.debug.show("commit_loan: person doesn't exist")
		return False
	if self._movie_id:
		movie = self.db.Movie.get_by(movie_id=self._movie_id)
		if not movie:
			self.debug.show("commit_loan: wrong movie_id")
			return False
	else:
		self.debug.show("commit_loan: movie not selected")
		return False

	# ask if user wants to loan whole collection
	loan_whole_collection = False
	if movie.collection_id>0:
		response = gutils.question(self, msg=_("Do you want to loan whole collection?"), parent=self.widgets['window'])
		if response == gtk.RESPONSE_YES:
			loan_whole_collection = True
		elif response == gtk.RESPONSE_CANCEL:
			return False
	
	loan = self.db.Loan(movie_id=movie.movie_id, person_id=person.person_id)
	if loan_whole_collection:
		loan.collection_id = movie.collection_id
	if movie.volume_id>0:
		loan.volume_id = movie.volume_id
	if loan.set_loaned():
		self.update_statusbar(_("Movie loaned"))
		self.treeview_clicked()

def return_loan(self):
	if self._movie_id:
		loan = self.db.Loan.get_by(movie_id=self._movie_id, return_date=None)
		if loan is None:
			movie = self.db.Movie.get_by(movie_id=self._movie_id)
			if movie.collection is not None and movie.collection.loaned:
				#print len(movie.loans) # FIXME: why it's == 0? (mappers problem?)
				loan = self.db.Loan.get_by(collection_id=movie.collection.collection_id, return_date=None)
			if movie.volume is not None and movie.volume.loaned:
				loan = self.db.Loan.get_by(volume_id=movie.volume.volume_id, return_date=None)
		if loan and loan.set_returned():
			self.treeview_clicked()

def get_loan_info(db, movie_id, volume_id=None, collection_id=None):
	"""Returns current collection/volume/movie loan data"""
	from sqlalchemy import and_, or_
	movie = db.Movie.get_by(movie_id=movie_id)
	if movie is None:
		return False
	
	# fix or add volume/collection data:
	if movie.collection_id is not None:
		collection_id = movie.collection_id
	if movie.volume_id is not None:
		volume_id = movie.volume_id
	
	if collection_id>0 and volume_id>0:
		return db.Loan.get_by(
				and_(or_(db.Loan.c.collection_id==collection_id,
						db.Loan.c.volume_id==volume_id,
						db.Loan.c.movie_id==movie_id),
					db.Loan.c.return_date==None))
	elif collection_id>0:
		return db.Loan.get_by(
				and_(or_(db.Loan.c.collection_id==collection_id,
						db.Loan.c.movie_id==movie_id)),
					db.Loan.c.return_date==None)
	elif volume_id>0:
		return db.Loan.get_by(and_(or_(db.Loan.c.volume_id==volume_id,
							db.Loan.c.movie_id==movie_id)),
						db.Loan.c.return_date==None)
	else:
		return db.Loan.get_by(db.Loan.c.movie_id==movie_id,db.Loan.c.return_date==None)

def get_loan_history(db, movie_id, volume_id=None, collection_id=None):
	"""Returns collection/volume/movie loan history"""
	from sqlalchemy import and_, or_, not_
	if collection_id>0 and volume_id>0:
		return db.Loan.select_by(and_(or_(db.Loan.c.collection_id==collection_id,
							db.Loan.c.volume_id==volume_id,
							db.Loan.c.movie_id==movie_id),
						not_(db.Loan.c.return_date==None)))
	elif collection_id>0:
		return db.Loan.select_by(and_(or_(db.Loan.c.collection_id==collection_id,
							db.Loan.c.movie_id==movie_id),
						not_(db.Loan.c.return_date==None)))
	elif volume_id>0:
		return db.Loan.select_by(and_(or_(db.Loan.c.volume_id==volume_id,
							db.Loan.c.movie_id==movie_id),
						not_(db.Loan.c.return_date==None)))
	else:
		return db.Loan.select_by(db.Loan.c.movie_id==movie_id,not_(db.Loan.c.return_date==None))




# -*- coding: UTF-8 -*-

__revision__ = '$Id: __init__.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2006-2007 Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published byp
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

# detect all plugins:
import glob, os.path

__all__ = [os.path.basename(x)[:-3] for x in glob.glob("%s/*.py" % os.path.dirname(__file__))]
__all__.remove('__init__')

class ImportPlugin:
	description = None
	author = None
	email = None
	version = None
	# file chooser:
	file_filters = None
	mime_types = None

	edit = False		# open add window for every movie?

	imported = 0
	data = None

	def __init__(self, parent, fields_to_import):
		self.db		= parent.db
		self.debug	= parent.debug
		self.locations	= parent.locations
		self.fields	= parent.field_names
		self.conditions	= parent._conditions
		self.colors	= parent._colors
		self.lang_types	= parent._lang_types
		self.layers	= parent._layers
		self.regions	= parent._regions
		self.widgets	= parent.widgets['import']
		self.fields_to_import = fields_to_import
		self._abort	= False

	def initialize(self):
		"""Initializes plugin (get all parameters from user, etc.)"""
		self.imported = 0
		return True

	def abort(self, *args):
		"""called after abort button clicked"""
		self._abort = True

	def set_source(self, name):
		"""Prepare source (open file, etc.)"""

	def count_movies(self):
		"""Returns number of movies in file which is about to be imported"""
		pass

	def get_movie_details(self):
		"""Returns dictionary with movie details"""
		pass

	def run(self, name):
		"""Import movies, function called in a loop over source files"""
		from add import validate_details, edit_movie
		from gutils import find_next_available
		from sqlalchemy import Select, func
		import gtk
		
		if not self.set_source(name):
			self.debug.show("Can't read data from file %s" % name)
			return False
		
		self.widgets['pwindow'].show()
		while gtk.events_pending():	# give GTK some time for updates
			gtk.main_iteration()

		# progressbar
		update_on = []
		count = self.count_movies()
		if count > 0:
			for i in range(0,100):
				update_on.append(int(float(i)/100*count))

		statement = Select( [ func.max(self.db.Movie.c.number) ] )
		number = statement.execute().fetchone()[0]
		if number is None:
			number = 1
		else:
			number += 1

		statement = Select([self.db.Movie.c.number])

		processed = 0
		while self._abort is False:
			details = self.get_movie_details()
			if details is None:
				break

			processed += 1
			if processed in update_on:
				self.widgets['progressbar'].set_fraction(float(processed)/float(count))
				gtk.main_iteration()
				self.widgets['progressbar'].set_text("%s (%s/%s)" % (str(self.imported), str(processed), str(count)))
				gtk.main_iteration()
				gtk.main_iteration() # extra iteration for abort button

			if (details.has_key('o_title') and details['o_title']) or (details.has_key('title') and details['title']):
				if details.has_key('o_title') and details['o_title']:
					statement.whereclause = func.lower(self.db.Movie.c.o_title)==details['o_title'].lower()
					if details.has_key('title') and details['title']:
						statement.append_whereclause( func.lower(self.db.Movie.c.title)==details['title'].lower() )
					tmp = statement.execute().fetchone()
					if tmp is not None:
						self.debug.show("movie already exists (number=%s, o_title=%s)" % (tmp.number, details['o_title']))
						continue
				elif details.has_key('title') and details['title']:
					statement.whereclause = func.lower(self.db.Movie.c.title)==details['title'].lower()
					tmp = statement.execute().fetchone()
					if tmp is not None:
						self.debug.show("movie already exists (number=%s, title=%s)" % (tmp.number, details['title']))
						continue
				validate_details(details, self.fields_to_import)
				if self.edit is True:
					response = edit_movie(self.parent, details)	# FIXME: wait until save or cancel button pressed
					if response == 1:
						self.imported += 1
				else:
					if not details.has_key('number') or (details.has_key('number') and details['number'] is None):
						#details['number'] = find_next_available(self.db)
						details['number'] = number
						number += 1
					#movie = self.db.Movie()
					#movie.add_to_db(details)
					try:
						self.db.Movie.mapper.mapped_table.insert().execute(details)
						self.imported += 1
					except Exception, e:
						self.debug.show("movie details are not unique, skipping: %s" % str(e))
			else:
				self.debug.show('skipping movie without title or original title')
		self.widgets['pwindow'].hide()
		return True

	def clear(self):
		"""clear plugin before next source file"""
		self.data = None
		self.imported = 0
		self.__source_name = None
		self._abort = False
	
	def destroy(self):
		"""close all resources"""
		pass


def on_import_plugin_changed(combobox, widgets, *args):
	from gtk import FileFilter
	import plugins.imp
	plugin_name = widgets['plugin'].get_active_text()
	__import__("plugins.imp.%s" % plugin_name)
	ip = eval("plugins.imp.%s.ImportPlugin" % plugin_name)
	widgets['author'].set_markup("<i>%s</i>" % ip.author)
	widgets['email'].set_markup("<i>%s</i>" % ip.email)
	widgets['version'].set_markup("<i>%s</i>" %ip.version)
	widgets['description'].set_markup("<i>%s</i>" %ip.description)
	# file filters
	for i in widgets['fcw'].list_filters():
		widgets['fcw'].remove_filter(i)
	f = FileFilter()
	f.set_name(plugin_name)
	if ip.file_filters is not None:
		if isinstance(ip.file_filters, tuple) or isinstance(ip.file_filters, list):
			for i in ip.file_filters:
				f.add_pattern(i)
		else:
			f.add_pattern(ip.file_filters)
	if ip.mime_types is not None:
		if isinstance(ip.mime_types, tuple) or isinstance(ip.mime_types, list):
			for i in ip.mime_types:
				f.add_mime_type(i)
		else:
			f.add_mime_type(ip.mime_types)
	widgets['fcw'].add_filter(f)
	f = FileFilter()
	f.set_name(_("All files"))
	f.add_pattern("*")
	widgets['fcw'].add_filter(f)

def on_import_button_clicked(button, self, *args):
	import plugins.imp, gutils
	plugin_name = self.widgets['import']['plugin'].get_active_text()
	filenames = self.widgets['import']['fcw'].get_filenames()
	
	fields = []
	w = self.widgets['import']['fields']
	for i in w:
		if w[i].get_active():
			fields.append(i)

	__import__("plugins.imp.%s" % plugin_name)
	ip = eval("plugins.imp.%s.ImportPlugin(self, fields)" % plugin_name)
	if ip.initialize():
		self.widgets['window'].set_sensitive(False)
		self.widgets['import']['window'].hide()
		self.widgets['import']['pabort'].connect('clicked', ip.abort, ip)
		for filename in filenames:
			self.widgets['import']['progressbar'].set_fraction(0)
			self.widgets['import']['progressbar'].set_text('')
			if ip.run(filename):
				gutils.info(self, _("%s file has been imported. %s movies added.") \
					% (plugin_name, ip.imported), self.widgets['window'])
				self.populate_treeview()
			ip.clear()
		ip.destroy()
		self.widgets['import']['pwindow'].hide()
		self.widgets['window'].set_sensitive(True)

def on_abort_button_clicked(button, self, *args):
	self.widgets['import']['window'].hide()
	self.widgets['import']['pwindow'].hide()
	self.widgets['window'].set_sensitive(True)




# -*- coding: UTF-8 -*-
# vim: fdm=marker

__revision__ = '$Id: PluginExportHTML.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2005-2007 Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import os
import sys
import gtk, gtk.glade
import gutils
import glob, shutil
import version
import math
from xml.dom import minidom

plugin_name         = 'HTML'
plugin_description  = _('Plugin exports data using templates')
plugin_author       = 'Piotr Ożarowski'
plugin_author_email = 'ozarow+griffith@gmail.com'
plugin_version      = '3.8'

class ExportPlugin(gtk.Window):
	#==[ configuration - default values ]==========={{{
	config = {
		'sorting'           : 'movies_title',
		'sorting2'          : 'ASC',
		'exported_dir'      : 'griffith_movies',
		'template'          : 0,
		'title'             : _("Griffith's movies list"),
		'style'             : 0,
		'custom_style'      : False,
		'custom_style_file' : None,
		'split_num'         : 50,		# split into x files/pages
		'split_by'          : 1,		# 0==files, 1==movies
		'seen_only'         : 0,		# 0==all movies; 1==seen only;   2==unseen only
		'loaned_only'       : 0,		# 0==all movies; 1==loaned only; 2==not loaned only
		'poster_convert'    : False,		# dont convert
		'poster_height'     : 200,
		'poster_width'      : 150,
		'poster_mode'       : 'RGB',		# RGB == color, L == black and white
		'poster_format'     : 'jpg'
	}
	fields = {
		'movies_cast'           : False,
		'movies_classification' : False,
		'movies_country'        : True,
		'movies_genre'          : True,
		'movies_director'       : True,
		'movies_image'          : True,
		'movies_o_site'         : True,
		'movies_site'           : True,
		'movies_trailer'        : True,
		'movies_loaned'         : False,
		'movies_media_num'      : True,
		'movies_number'         : True,
		'movies_o_title'        : True,
		'movies_plot'           : False,
		'movies_rating'         : True,
		'movies_runtime'        : True,
		'movies_studio'         : False,
		'movies_seen'           : True,
		'movies_title'          : True,
		'movies_year'           : True,
		'movies_notes'          : False,
#		'movies_region'         : False,
#		'movies_layers'         : False,
#		'movies_condition'      : False,
#		'movies_color'          : False,
#		'movies_volume_id'      : False,
#		'movies_collection_id'  : False,
		'media_name'            : True,
		'collections_name'      : True,
		'volumes_name'          : True,
#		'acodecs_name'          : True,
		'vcodecs_name'          : True,
	}
	
	fields_as_columns = {
		'movies_cast'           : 'cast',
		'movies_classification' : 'classification',
		'movies_country'        : 'country',
		'movies_genre'          : 'genre',
		'movies_director'       : 'director',
		'movies_image'          : 'image',
		'movies_o_site'         : 'o_site',
		'movies_site'           : 'site',
		'movies_trailer'        : 'trailer',
		'movies_loaned'         : 'loaned',
		'movies_media_num'      : 'media_num',
		'movies_number'         : 'number',
		'movies_o_title'        : 'o_title',
		'movies_plot'           : 'plot',
		'movies_rating'         : 'rating',
		'movies_runtime'        : 'runtime',
		'movies_studio'         : 'studio',
		'movies_seen'           : 'seen',
		'movies_title'          : 'title',
		'movies_year'           : 'year',
		'movies_notes'          : 'notes',
#		'movies_region'         : 'region',
#		'movies_layers'         : 'layers',
#		'movies_condition'      : 'condition',
#		'movies_color'          : 'color',
#		'movies_volume_id'      : 'volume_id',
#		'movies_collection_id'  : 'collection_id',
		'media_name'            : 'name',
		'collections_name'      : 'name',
		'volumes_name'          : 'name',
#		'acodecs_name'          : 'name',
		'vcodecs_name'          : 'name',
	}
	
	names = {
		_('Cast')           : 'movies_cast',
		_('Classification') : 'movies_classification',
		_('Country')        : 'movies_country',
		_('Director')       : 'movies_director',
		_('Genre')          : 'movies_genre',
		_('Image')          : 'movies_image',
		_('Official site')  : 'movies_o_site',
		_('Site')           : 'movies_site',
		_('Trailer')        : 'movies_trailer',
		_('Loaned')         : 'movies_loaned',
		_('Discs')          : 'movies_media_num',
		_('Number')         : 'movies_number',
		_('Original Title') : 'movies_o_title',
		_('Plot')           : 'movies_plot',
		_('Rating')         : 'movies_rating',
		_('Runtime')        : 'movies_runtime',
		_('Studio')         : 'movies_studio',
		_('Seen it')        : 'movies_seen',
		_('Title')          : 'movies_title',
		_('Year')           : 'movies_year',
		_('Notes')          : 'movies_notes',
#		_('Region')         : 'movies_region',
#		_('Layers')         : 'movies_layers',
#		_('Condition')      : 'movies_condition',
#		_('Color')          : 'movies_color',
#		_('Volume')         : 'movies_volume_id',
#		_('Collection')     : 'movies_collection_id',
		_('Media')          : 'media_name',
		_('Collection')     : 'collections_name',
		_('Volume')         : 'volumes_name',
#		_('Audio codecs')   : 'acodecs_name',
		_('Video codec')    : 'vcodecs_name',
	}
	#}}}

	def __init__(self, database, locations, parent_window, debug, **kwargs):#{{{
		self.db = database
		self.debug = debug
		self.locations = locations
		if kwargs.has_key('config'):
			self.persistent_config = kwargs['config']
		else:
			self.persistent_config = None
		self.widgets = {}
		self.style_list = {}
		self.templates = self.make_template_list()
		# glade
		gf = os.path.join(locations['glade'], 'exporthtml.glade')
		self.define_widgets(gtk.glade.XML(gf))
		self.fill_widgets()
	#}}}

	def get_node_value_by_language(self, parent, name, language='en'):#{{{
		nodes = parent.getElementsByTagName(name)
		for node in nodes:
			if node.parentNode != parent:
				continue
			elif node.attributes.get('xml:lang') is not None:
				if node.attributes.get('xml:lang').value == language:
					return node.firstChild.nodeValue
			else:	# set default value in case node has no xml:lang attribute
				value = node.firstChild.nodeValue
		return value
	#}}}		
		
	def make_template_list(self):#{{{
		language = 'en'
		if os.environ.has_key('LANG'):
			language = os.environ['LANG'][:2]
		templates = {}
		j=0 # number of templates
		dirName = os.path.join(self.locations['share'], 'export_templates')
		items = os.listdir(dirName)
		items.sort()
		for i in items:
			fileName = os.path.join(dirName, i)
			if not os.path.islink(fileName) and os.path.isdir(fileName):
				# clear previous data
				doc = None; styles = {};
				tpl_name=None; tpl_author=None; tpl_email=None; tpl_version=None; tpl_ext=None; tpl_desc=None
				try:
					doc = minidom.parse(os.path.join(fileName, 'config.xml'))
				except:
					self.debug.show("Can't parse configuration file for template: %s"%fileName)
					continue
				for template in doc.getElementsByTagName('template'):
					tpl_name    = self.get_node_value_by_language(template, 'name', language)
					tpl_author  = template.getElementsByTagName('author')[0].firstChild.nodeValue
					tpl_email   = template.getElementsByTagName('email')[0].firstChild.nodeValue
					tpl_version = template.getElementsByTagName('version')[0].firstChild.nodeValue
					tpl_ext     = template.getElementsByTagName('extension')[0].firstChild.nodeValue
					tpl_desc    = self.get_node_value_by_language(template, 'description', language)
					k=0	# number of styles
					try:
						styles_list = template.getElementsByTagName('styles')[0].getElementsByTagName('style')
						for style in styles_list:
							tpl_style_name = self.get_node_value_by_language( style, 'name', language )
							tpl_style_file = style.getElementsByTagName('file')[0].firstChild.nodeValue
							# get preview if available
							try:
								tpl_style_preview = style.getElementsByTagName('preview')[0].firstChild.nodeValue
							except:
								tpl_style_preview = None
							styles[k] = {
								'name': tpl_style_name,
								'file': tpl_style_file,
								'preview': tpl_style_preview
							}
							k=k+1
					except:
						styles = None
				if tpl_name=='':
					continue
				templates[j]= {
					'dir'     : i,
					'name'    : tpl_name,
					'author'  : tpl_author,
					'email'   : tpl_email,
					'version' : tpl_version,
					'ext'     : tpl_ext,
					'desc'    : tpl_desc,
					'styles'  : styles
				}
				j=j+1
		return templates
	#}}}

	#==[ widgets ]=================================={{{
	def define_widgets(self, glade_file):
		get = lambda x: glade_file.get_widget(x)
		self.widgets = {
			'window'                : get('w_eh'),
			'fcw'                   : get('fcw'),
			'box_include_1'         : get('box_include_1'),
			'box_include_2'         : get('box_include_2'),
			'box_include_3'         : get('box_include_3'),
			'sb_split_num'          : get('sb_split_num'),
			'rb_split_files'        : get('rb_split_files'),
			'rb_split_movies'       : get('rb_split_movies'),
			'rb_seen'               : get('rb_seen'),
			'rb_seen_only'          : get('rb_seen_only'),
			'rb_seen_only_n'        : get('rb_seen_only_n'),
			'rb_loaned'             : get('rb_loaned'),
			'rb_loaned_only'        : get('rb_loaned_only'),
			'rb_loaned_only_n'      : get('rb_loaned_only_n'),
			'entry_header'          : get('entry_header'),
			'cb_custom_style'       : get('cb_custom_style'),
			'cb_reverse'            : get('cb_reverse'),
			'combo_style'           : get('combo_style'),
			'combo_sortby'          : get('combo_sortby'),
			'combo_theme'           : get('combo_theme'),
			'fcb_custom_style_file' : get('fcb_custom_style_file'),
			'l_tpl_author'          : get('l_tpl_author'),
			'l_tpl_email'           : get('l_tpl_email'),
			'l_tpl_version'         : get('l_tpl_version'),
			'l_tpl_desc'            : get('l_tpl_desc'),
			'image_preview'         : get('image_preview'),
			'vb_posters'            : get('vb_posters'),
			'sb_height'             : get('sb_height'),
			'sb_width'              : get('sb_width'),
			'cb_black'              : get('cb_black'),
			'combo_format'          : get('combo_format'),
			'cb_convert'            : get('cb_convert'),
		}

		# define handlers for general events
		glade_file.signal_autoconnect({
			'on_export_button_clicked'           : self.export_data,
			'on_rb_split_files_toggled'          : self.on_rb_split_files_toggled,
			'on_rb_split_movies_toggled'         : self.on_rb_split_movies_toggled,
			'on_rb_seen_toggled'                 : self.on_rb_seen_toggled,
			'on_rb_seen_only_toggled'            : self.on_rb_seen_only_toggled,
			'on_rb_seen_only_n_toggled'          : self.on_rb_seen_only_n_toggled,
			'on_rb_loaned_toggled'               : self.on_rb_loaned_toggled,
			'on_rb_loaned_only_toggled'          : self.on_rb_loaned_only_toggled,
			'on_rb_loaned_only_n_toggled'        : self.on_rb_loaned_only_n_toggled,
			'on_cancel_button_clicked'           : self.on_quit,
			'on_cb_data_toggled'                 : self.on_cb_data_toggled,
			'on_cb_custom_style_toggled'         : self.on_cb_custom_style_toggled,
			'on_fcb_custom_style_file_activated' : self.on_fcb_custom_style_file_activated,
			'on_combo_style_changed'             : self.on_combo_style_changed,
			'on_combo_theme_changed'             : self.on_combo_theme_changed,
			'on_cb_convert_toggled'              : self.on_cb_convert_toggled,
		})

	def fill_widgets(self):
		# themes
		for i in self.templates:
			self.widgets['combo_theme'].insert_text(i, self.templates[i]['name'])

		# sortby combo
		keys = self.names.keys()
		keys.sort()
		j = 0
		pos_o_title = 0
		for i in keys:
			self.widgets['combo_sortby'].append_text(i)
			if i == _('Original Title'):
				pos_o_title = j
			j = j + 1
		self.widgets['combo_sortby'].set_wrap_width(3)

		# include data
		j = 0
		k = math.ceil( len(self.names) / float(3) )
		for i in keys:
			j = j + 1
			field = self.names[i]
			self.widgets['cb_'+field] = gtk.CheckButton(i)
			self.widgets['cb_'+field].set_name("cb_%s" % field)
			self.widgets['cb_'+field].connect('toggled', self.on_cb_data_toggled)
			self.widgets['cb_'+field].set_active(self.fields[field])
			if j <= k:
				self.widgets['box_include_1'].add(self.widgets["cb_%s" % field])
			elif j<= 2*k:
				self.widgets['box_include_2'].add(self.widgets["cb_%s" % field])
			else:
				self.widgets['box_include_3'].add(self.widgets["cb_%s" % field])
		self.widgets['box_include_1'].show_all()
		self.widgets['box_include_2'].show_all()
		self.widgets['box_include_3'].show_all()

		# set defaults --------------------------------
		self.widgets['entry_header'].set_text(self.config['title'])
		self.widgets['combo_theme'].set_active(2)	# html_tables
		self.widgets['combo_sortby'].set_active(pos_o_title)	# orginal title
		# spliting
		self.widgets['sb_split_num'].set_value(self.config['split_num'])
		if self.config['split_by'] == 0:
			self.widgets['rb_split_files'].set_active(True)
		else:
			self.widgets['rb_split_movies'].set_active(True)
		# limiting
		if self.config['seen_only'] == 2:
			self.widgets['rb_seen_only_n'].set_active(True)
		elif self.config['seen_only'] == 1:
			self.widgets['rb_seen_only'].set_active(True)
		else:
			self.widgets['rb_seen'].set_active(True)
		if self.config['loaned_only'] == 2:
			self.widgets['rb_loaned_only_n'].set_active(True)
		elif self.config['loaned_only'] == 1:
			self.widgets['rb_loaned_only'].set_active(True)
		else:
			self.widgets['rb_loaned'].set_active(True)
		# posters
		self.widgets['combo_format'].set_active(0)
		if self.config['poster_convert'] and self.config['poster_convert'] == True:
			self.widgets['cb_convert'].set_active(True)
			self.widgets['vb_posters'].set_sensitive(True)
		else:
			self.widgets['cb_convert'].set_active(False)
			self.widgets['vb_posters'].set_sensitive(False)
		# persistent config
		if not self.persistent_config is None:
			tmp = self.persistent_config.get('export_dir', None, section='export-html')
			if not tmp is None:
				self.widgets['fcw'].set_current_folder(tmp)
	#}}}

	#==[ callbacks ]================================{{{
	# buttons:
	def on_quit(self, widget=None):
		self.widgets['window'].destroy()

	# data tab -------------------------------------#{{{
	def on_rb_split_files_toggled(self, widget):
		self.config['split_by'] = 0	# files

	def on_rb_split_movies_toggled(self, widget):
		self.config['split_by'] = 1	# movies
	
	# export frame
	def on_cb_data_toggled(self, widget):
		self.fields[gutils.after(widget.get_name(), 'cb_')] = widget.get_active()

	# limit frame
	def on_rb_seen_toggled(self, widget):
		if widget.get_active():
			self.config['seen_only'] = 0	# export all movies

	def on_rb_seen_only_toggled(self, widget):
		if widget.get_active():
			self.config['seen_only'] = 1	# export only seen movies
	
	def on_rb_seen_only_n_toggled(self, widget):
		if widget.get_active():
			self.config['seen_only'] = 2	# export only unseen movies
	
	def on_rb_loaned_toggled(self, widget):
		if widget.get_active():
			self.config['loaned_only'] = 0	# export all movies

	def on_rb_loaned_only_toggled(self, widget):
		if widget.get_active():
			self.config['loaned_only'] = 1	# export only loaned movies
	
	def on_rb_loaned_only_n_toggled(self, widget):
		if widget.get_active():
			self.config['loaned_only'] = 2	# export only not loaned movies
	
	# posters frame
	def on_cb_convert_toggled(self, widget):
		active = widget.get_active()
		self.config['poster_convert'] = active
		if not active:
			self.widgets['vb_posters'].set_sensitive(False)
		else:
			self.widgets['vb_posters'].set_sensitive(True)
	#}}}

	# template tab ---------------------------------#{{{
	def on_combo_theme_changed(self, widget):
		old_id = self.config['template']
		tpl_id = widget.get_active()
		self.config['template'] = tpl_id
		# fill authors data
		self.widgets['l_tpl_author'].set_markup("<i>%s</i>" % self.templates[tpl_id]['author'])
		self.widgets['l_tpl_email'].set_markup("<i>%s</i>" % self.templates[tpl_id]['email'])
		self.widgets['l_tpl_email'].set_selectable(True)
		self.widgets['l_tpl_version'].set_markup("<i>%s</i>" % self.templates[tpl_id]['version'])
		self.widgets['l_tpl_desc'].set_markup("<i>%s</i>" % self.templates[tpl_id]['desc'])
		# remove old style list
		self.widgets['combo_style'].get_model().clear()
		# ... and add new
		if self.templates[tpl_id]['styles'] is not None:
			for i in self.templates[tpl_id]['styles']:
				self.widgets['combo_style'].insert_text(i, self.templates[tpl_id]['styles'][i]['name'])	# template name
			self.widgets['combo_style'].set_active(0)
		else:
			self.config['style'] = None
			self.widgets['image_preview'].set_from_stock(gtk.STOCK_MISSING_IMAGE, gtk.ICON_SIZE_LARGE_TOOLBAR)

	def on_combo_style_changed(self, widget):
		self.config['style'] = widget.get_active()
		self.widgets['cb_custom_style'].set_active(False)
		preview_file = None

		tpl_id = self.config['template']
		template_dir = os.path.join(self.locations['share'], 'export_templates', self.templates[tpl_id]['dir'])
		if self.config['style'] > -1:
			preview_file = self.templates[self.config['template']]['styles'][self.config['style']]['preview']
		if preview_file is not None:
			preview_file = os.path.join(template_dir, preview_file)
		if preview_file is not None and not os.path.isfile(preview_file):
			preview_file = os.path.join(template_dir, 'preview.jpg')	# try default preview image
			if not os.path.isfile(preview_file):
				preview_file = None
		if preview_file is not None:
			self.widgets['image_preview'].set_from_file(preview_file)
		else:
			self.widgets['image_preview'].set_from_stock(gtk.STOCK_MISSING_IMAGE, gtk.ICON_SIZE_LARGE_TOOLBAR)
		self.widgets['image_preview'].show()

	def on_cb_custom_style_toggled(self, widget):
		if widget.get_active():
			self.config['custom_style'] = True
			self.widgets['image_preview'].hide()
		else:
			self.config['custom_style'] = False
			self.widgets['image_preview'].show()

	def on_fcb_custom_style_file_activated(self, widget):
		self.config['custom_style_file'] = widget.get_filename()
		self.widgets['cb_custom_style'].set_active(True)
	#}}} }}}

	def make_navigation(self, pages, current):#{{{
		if pages > 1:	# navigation needed
			tpl_id = self.config['template']
			t = '<div class="navi">\n\t<p id="prev">'
			if current > 1:
				t += '<a href="./page_%s.%s">%s</a>' % \
					(str(current-1), self.templates[tpl_id]['ext'], _('previous'))
			else:	# first page
				t += _('previous')
			t += "</p>\n"
			for i in range(1, pages+1):
				if i == current:
					t +='\t<p id="current">%s</p>\n' % str(i)
				else:
					t +='\t<p><a href="./page_%s.%s">%s</a></p>\n' % \
						(str(i), self.templates[tpl_id]['ext'], str(i))
			t += '\t<p id="next">'
			if pages > current:
				t +='<a href="./page_%s.%s">%s</a>' % \
						(str(current+1), self.templates[tpl_id]['ext'], _('next'))
			else:	# last page
				t += _('next')
			t += "</p>\n</div>"
			return t
		else:
			return ''
	#}}}

	def fill_template(self, template, field, data='', title='', remove=False):	#{{{
		start = template.find('<@'+ field +'>')
		end = template.find('</@'+ field +'>', start+1)
		if start > -1 and end > -1:
			if remove == True:
				return template[:start] + template[end+4+len(field):]
			else:
				tmp = gutils.trim(template,'<@'+field+'>', '</@'+field+'>')
				tmp = tmp.replace("@DATA@", data)
				tmp = tmp.replace("@TITLE@", title)
				tmp = template[:start] + tmp + template[end+4+len(field):]
				if tmp.find('<@'+ field +'>') != -1:
					tmp = self.fill_template(tmp, field, data, title, remove)
				return tmp
		else:
			return template
	#}}}

	def select(self):	#{{{
		from sqlalchemy import select
		config = self.config
		
		# columns to select
		columns = []
		for i in self.fields_as_columns:
			try:
				columns.append(self.db.Movie.c[self.fields_as_columns[i]])
			except:
				pass
		# use outer join to media table to get the name of the media
		from sqlalchemy import outerjoin
		columns.append(self.db.Medium.c['name'])
		media_join = outerjoin(self.db.metadata.tables['movies'], \
			self.db.metadata.tables['media'], \
			self.db.metadata.tables['movies'].c.medium_id==self.db.metadata.tables['media'].c.medium_id)
		# use outer join to collections table to get the name of the collection
		columns.append(self.db.Collection.c['name'])
		collection_join = media_join.outerjoin( \
			self.db.metadata.tables['collections'], \
			self.db.metadata.tables['movies'].c.collection_id==self.db.metadata.tables['collections'].c.collection_id)
		# use outer join to volumes table to get the name of the volume
		columns.append(self.db.Volume.c['name'])
		volume_join = collection_join.outerjoin( \
			self.db.metadata.tables['volumes'], \
			self.db.metadata.tables['movies'].c.volume_id==self.db.metadata.tables['volumes'].c.volume_id)
		# use outer join to volumes table to get the name of the volume
		columns.append(self.db.VCodec.c['name'])
		vcodec_join = volume_join.outerjoin( \
			self.db.metadata.tables['vcodecs'], \
			self.db.metadata.tables['movies'].c.vcodec_id==self.db.metadata.tables['vcodecs'].c.vcodec_id)
		#
		# selecting the audio codec doesn't work with joins because if more than one codec per movie is
		# added it would duplicate the movie in the result set as many as audio codecs are added to the movie
		#
		# use outer join to language and acodec table to get the name of the audio codec
		#movie_lang_join = vcodec_join.outerjoin( \
		#	self.db.metadata.tables['movie_lang'], \
		#	self.db.metadata.tables['movies'].c.movie_id==self.db.metadata.tables['movie_lang'].c.movie_id)
		#columns.append(self.db.ACodec.c['name'])
		#acodec_join = movie_lang_join.outerjoin( \
		#	self.db.metadata.tables['acodec'], \
		#	self.db.metadata.tables['movie_lang'].c.acodec_id==self.db.metadata.tables['acodec'].c.acodec_id)
		
		# sort order	TODO: more than one sort column
		sort_columns = []
		sorting_parts = config['sorting'].split('_')
		if config['sorting2'] == 'ASC':
			from sqlalchemy import asc
			sort_columns.append(asc(self.db.metadata.tables[sorting_parts[0]].c['_'.join(sorting_parts[1:])]))
		elif config['sorting2'] == 'DESC':
			from sqlalchemy import desc
			sort_columns.append(desc(self.db.metadata.tables[sorting_parts[0]].c['_'.join(sorting_parts[1:])]))

		statement = select(columns=columns, order_by=sort_columns, from_obj=[media_join, collection_join, volume_join, vcodec_join], use_labels = True)

		# where clause
		if config['seen_only'] == 1:
			statement.append_whereclause(self.db.Movie.c.seen==True)
		elif config['seen_only'] == 2:
			statement.append_whereclause(self.db.Movie.c.seen!=True)
		if config['loaned_only'] == 1:
			statement.append_whereclause(self.db.Movie.c.loaned==True)
		elif config['loaned_only'] == 2:
			statement.append_whereclause(self.db.Movie.c.loaned!=True)
		
		return statement.execute()
	#}}}

	#==[ main function ]============================{{{
	def export_data(self, widget):
		"""Main exporting function"""

		config = self.config
		fields = self.fields
		tid = config['template']
		
		# get data from widgets
		self.config['exported_dir'] = self.widgets['fcw'].get_filename()
		self.config['title']        = self.widgets['entry_header'].get_text().decode('utf-8')
		self.config['sorting']      = self.names[self.widgets['combo_sortby'].get_active_text().decode('utf-8')]
		if self.widgets['cb_reverse'].get_active():
			self.config['sorting2'] = 'DESC'
		else:
			self.config['sorting2'] = 'ASC'
		self.config['split_num']     = self.widgets['sb_split_num'].get_value_as_int()
		self.config['poster_height'] = self.widgets['sb_height'].get_value_as_int()
		self.config['poster_width']  = self.widgets['sb_width'].get_value_as_int()
		if self.widgets['cb_black'].get_active():
			self.config['poster_mode'] = 'L'
		else:
			self.config['poster_mode'] = 'RGB'
		self.config['poster_format'] = self.widgets['combo_format'].get_active_text()

		# create directories
		if not config['exported_dir']:
			self.debug.show("Error: Folder name not set!")
			return 1
		
		if not os.path.isdir(config['exported_dir']):
			try:
				os.mkdir(config['exported_dir'])
			except:
				gutils.error(self,_("Can't create %s!") % config['exported_dir'])
				return 2
			
		data_path = os.path.join(self.locations['share'], 'export_templates', self.templates[tid]['dir'], 'data')
		if os.path.isdir(data_path):
			try:
				gutils.copytree(data_path, config['exported_dir'])
			except Exception, err:
				gutils.warning(self, str(err))
		
		# persist config
		if not self.persistent_config is None:
			self.persistent_config.set('export_dir', config['exported_dir'], section='export-html')
			self.persistent_config.save()

		if fields['movies_image']:
			# import modules needed later
			# modules are needed at least to convert griffith.png to nopic.(gif|jpeg|png)
			from PIL import Image
			# py2exe problem workaround:
			# if self.windows:
			from PIL import PngImagePlugin
			from PIL import GifImagePlugin
			from PIL import JpegImagePlugin
			Image._initialized=2
			# end if
			if not config['poster_convert']:
				config['poster_format'] = 'jpeg' # replace 'jpeg'
			
			posters_dir = os.path.join(config['exported_dir'], 'posters')
			if os.path.isdir(posters_dir):
				if gutils.question(self, _("Directory %s already exists.\nDo you want to overwrite it?") % posters_dir,1,self) == gtk.RESPONSE_YES:
					try:
						shutil.rmtree(posters_dir)
					except:
						gutils.error(self,_("Can't remove %s!") % config['exported_dir'])
						return 3
				else:
					return 4
			try:
				os.mkdir(posters_dir)
			except:
				gutils.error(self,_("Can't create %s!") % posters_dir)
				return 5

		if config['custom_style']:
			if config['custom_style_file'] is not None and os.path.isfile(config['custom_style_file']):
				try:
					shutil.copy(config['custom_style_file'],config['exported_dir'])
				except:
					gutils.warning(self,_("Can't copy %s!")%style_file)
					config['custom_style'] = False
				style = os.path.split(self.config['custom_style_file'])[1]
			else:
				config['custom_style'] = False


		if config['style'] is not None and config['custom_style']==False:
			style = self.templates[tid]['styles'][config['style']]['file']
			style_path = os.path.join(self.locations['share'], 'export_templates', self.templates[tid]['dir'], style)
			try:
				shutil.copy(style_path,config['exported_dir'])
			except:
				gutils.warning(self,_("Can't copy %s!")%style_path)

		# select exported movies
		exported_movies = self.select().fetchall()
		number_of_exported_movies = len(exported_movies)

		if config['split_by'] == 1:	# split by number of movies per page
			self.entries_per_page = config['split_num']
		else:				# split by number of pagess
			if number_of_exported_movies < config['split_num']:
				self.entries_per_page = 1
			else:
				self.entries_per_page = int(number_of_exported_movies / config['split_num'])

		# calculate number of files to be created (pages)
		self.pages = int(math.ceil(float(number_of_exported_movies) / self.entries_per_page))

		template_dir = os.path.join(self.locations['share'], 'export_templates', self.templates[tid]['dir'])
		try:
			filename = 'page.tpl'
			tpl_header = file(os.path.join(template_dir,filename), "r").read()
		except:
			gutils.error(self,_("Can't open %s!")%filename)
			return False

		tpl_header = self.fill_template(tpl_header, 'header', config['title'])
		try:
			tpl_header = self.fill_template(tpl_header, 'style', style)
		except:
			pass
		tmp = _('Document generated by Griffith v') + version.pversion + \
				' - Copyright (C) ' + version.pyear + ' ' + version.pauthor + ' - ' + \
				_('Released Under the GNU/GPL License')
		tmp = gutils.html_encode(tmp)
		tmp = tmp.replace('@', ' at ')	# prevent spam
		tpl_header = self.fill_template(tpl_header, 'copyright', tmp)
		tmp = None
		
		tpl_header = self.fill_template(tpl_header, 'pages', self.pages)
		
		# count exported fields
		rowspan = 0
		for i in fields:
			if fields[i] == True:
				rowspan = rowspan + 1
		rowspan = str(rowspan)
		tpl_header = self.fill_template(tpl_header, 'rowspan', rowspan)

		# split template
		tpl_tail = gutils.after(tpl_header, '<!-- /ITEMS -->')
		tpl_item = gutils.trim(tpl_header, '<!-- ITEMS -->','<!-- /ITEMS -->')
		tpl_header = gutils.before(tpl_header, '<!-- ITEMS -->')

		# fill header
		for j in self.names:
			if self.fields[self.names[j]] == True:
				tpl_header = self.fill_template(tpl_header, self.names[j], '', j)
			else:
				tpl_header = self.fill_template(tpl_header, self.names[j], remove=True)

		# check if line break needs conversion
		if tpl_header.upper().find('XHTML 1.0') > -1:
			linebreak_replacement = '<br />'
		else:
			linebreak_replacement = None

		item=1	# item's position on page (1 - first, ...)
		i = 1
		page=1	# page number
		for row in exported_movies:	# fill items {{{
			# check if new file has to be created
			if item==1:
				filename = os.path.join(config['exported_dir'],'page_%s.' % page + self.templates[tid]['ext'])
				try:
					exported_file = file(filename, 'w')
				except:
					gutils.error(self,_("Can't create %s!")%filename)
					return False
				tmp2 = tpl_header + ''
				exported_file.write(self.fill_template(tmp2, 'page', str(page)))
				tmp2 = None

			# ---------------------------------------------
			tmp = tpl_item + '' # a copy (not a reference!)
			tmp = self.fill_template(tmp, 'id', str(item))
			tmp = self.fill_template(tmp, 'item', str(i))
			for j in self.names:
				if self.fields[self.names[j]] == True:
					if self.names[j] == 'movies_image':
						if row['movies_image']:
							#image = row['movies_image'] + '.' + config['poster_format'].lower()
							image = '%d' % row['movies_number'] + '.' + config['poster_format'].lower()
							tmp = self.fill_template(tmp, self.names[j], image, j)
						else:
							tmp = self.fill_template(tmp, self.names[j], 'nopic.' + config['poster_format'].lower(), j)
					elif row[self.names[j]] is None:
						tmp = self.fill_template(tmp, self.names[j], '', j)
					elif row[self.names[j]] is True:
						tmp = self.fill_template(tmp, self.names[j], _('Yes'), j)
					elif row[self.names[j]] is False:
						tmp = self.fill_template(tmp, self.names[j], _('No'), j)
					else:
						try:
							data = str(row[self.names[j]]).encode('utf-8')
							if linebreak_replacement is not None:
								data = data.replace('\r\n', linebreak_replacement)
								data = data.replace('\n', linebreak_replacement)
							tmp = self.fill_template(tmp, self.names[j], data, j)
						except UnicodeDecodeError:
							self.debug.show("Unicode Decode Error occurred while decoding %s (movie number: %s)" % (self.names[j], row['movies_number']))
							data = str(row[self.names[j]])
							if linebreak_replacement is not None:
								data = data.replace('\r\n', linebreak_replacement)
								data = data.replace('\n', linebreak_replacement)
							tmp = self.fill_template(tmp, self.names[j], data, j)
						except Exception, ex:
							self.debug.show("Error occurred while decoding %s (movie number: %s)" % (self.names[j], row['movies_number']))
				else:
					tmp = self.fill_template(tmp, self.names[j], remove=True)
				tmp = gutils.convert_entities(tmp)
			exported_file.write(tmp)
			tmp = None
			# ---------------------------------------------
			
			# copy poster
			if fields['movies_image']:
				if row['movies_image'] is not None:
					image_file_src = os.path.join(self.locations['posters'], str(row['movies_image']) + '.jpg')
					image_file_dst = os.path.join(posters_dir, '%d' % row['movies_number']) + '.' + config['poster_format'].lower()
					if not config['poster_convert']:	# copy file
						try:
							shutil.copy(image_file_src,	image_file_dst)
						except:
							self.debug.show("Can't copy %s" % image_file_src)
					else:	# convert posters
						try:
							im = Image.open(image_file_src, 'r').convert(config['poster_mode'])
							im.thumbnail((config['poster_width'], config['poster_height']), Image.ANTIALIAS)
							im.save(image_file_dst, config['poster_format'])
						except:
							self.debug.show("Can't convert %s" % image_file_src)

			# close file if last item
			if ((page-1)*self.entries_per_page)+item == number_of_exported_movies:
				tmp2 = tpl_tail + ''
				exported_file.write(self.fill_template(tmp2, 'navigation', self.make_navigation(self.pages, page)))
				exported_file.close()
				tmp2 = None
			
			# close file if last item in page
			elif item == self.entries_per_page:
				tmp2 = tpl_tail + ''
				exported_file.write(self.fill_template(tmp2, 'navigation', self.make_navigation(self.pages, page)))
				exported_file.close()
				page = page+1
				item=1
				tmp2 = None
			else:
				item=item+1
			i=i+1
		#}}}
		# convert/copy the griffith picture for movies without a poster
		image_file_src = os.path.join(self.locations['images'], 'griffith.png')
		image_file_dst = os.path.join(posters_dir, 'nopic.' + config['poster_format'].lower())
		try:
			if config['poster_convert']:
				im = Image.open(image_file_src, 'r').convert(config['poster_mode'])
				im.thumbnail((config['poster_width'], config['poster_height']), Image.ANTIALIAS)
			else:
				im = Image.open(image_file_src, 'r')
			im.save(image_file_dst, config['poster_format'])
		except:
			self.debug.show("Can't convert %s" % image_file_src)
		gutils.info(self, _("Document has been generated."), self)
		self.on_quit()
	#}}}




# -*- coding: UTF-8 -*-

__revision__ = '$Id: PluginMovieCineMovies.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie,string

plugin_name = "Cinemovies"
plugin_description = "Cinemovies"
plugin_url = "www.cinemovies.fr"
plugin_language = _("French")
plugin_author = "Vasco Nunes"
plugin_author_email="<vasco.m.nunes@gmail.com>"
plugin_version = "0.2"

class Plugin(movie.Movie):
	def __init__(self, id):
		self.encode='iso-8859-1'
		self.movie_id = id
		self.url = "http://www.cinemovies.fr/fiche_film.php?IDfilm=" + str(self.movie_id)

	def get_image(self):
		self.image_url = "http://www.cinemovies.fr/images/data/films/Pfilm"
		self.image_url = self.image_url + string.strip(gutils.trim(self.page,"data/films/Pfilm",".jpg")) + ".jpg"

	def get_o_title(self):
		self.o_title = string.capwords(gutils.trim(self.page,"Titre original</b></td>","</td>"))

	def get_title(self):
		self.title = string.capwords(gutils.trim(self.page,"<TR><TD class=\"arial12blacknews\">"," :</TD></TR><TR><TD"))

	def get_director(self):
		self.director = string.strip(gutils.trim(self.page," par:</b></td>","</a>"))

	def get_plot(self):
		self.plot = gutils.trim(self.page,"L'histoire</font></td>","</p><br>")

	def get_year(self):
		self.year = gutils.trim(self.page,"<B>Ano:</B> <FONT SIze=-1>","</FONT>")

	def get_runtime(self):
		self.runtime = gutils.trim(self.page,"height=\"12\">Durée: ","</td>")

	def get_genre(self):
		self.genre = gutils.trim(self.page,"Genre: ","</b></a>")

	def get_cast(self):
		self.cast = ""
		self.cast = gutils.trim(self.page,"<b>Avec:</b>","</tr>")

	def get_classification(self):
		self.classification = gutils.trim(self.page,"<B>Idade:</B> <FONT SIze=-1>","</FONT>")

	def get_studio(self):
		self.studio = string.strip(gutils.trim(self.page,"&nbsp;Studio/Distributeur</b></td>","</td>"))

	def get_o_site(self):
		self.o_site = gutils.trim(self.page,"<A HREF='", "' TARGET=_blank><IMG SRC='/imagens/bf_siteoficial.gif'")

	def get_site(self):
		self.site = gutils.trim(self.page,"/imagens/bf_siteoficial.gif' WIDTH=89 HEIGHT=18 BORDER=0 ALT=''>", "' TARGET=_blank><IMG SRC='/imagens/bf_imdb.gif'")
		self.site = gutils.after(self.site,"<A HREF='")
		self.site = string.replace(self.site,"'","")

	def get_trailer(self):
		self.trailer = gutils.trim(self.page,"/imagens/bf_imdb.gif' WIDTH=89 HEIGHT=18 BORDER=0 ALT=''>", "' TARGET=_blank><IMG SRC='/imagens/bf_trailer.gif'")
		self.trailer = gutils.after(self.trailer,"<A HREF='")

	def get_country(self):
		self.country = string.strip(gutils.trim(self.page,"&nbsp;Pays</b></td>","</td>"))

	def get_rating(self):
		tmp_rating = gutils.trim(self.page,"<td width=\"100%\" class=\"arial12blacknews\"><p align=\"center\"><font size=\"5\">","/5</font></td>")
		if tmp_rating != "":
			self.rating = str(float(tmp_rating)*2)
		else:
			self.rating = ""

class SearchPlugin(movie.SearchMovie):
	def __init__(self):
		self.encode='iso-8859-1'
		self.original_url_search	= "http://www.cinemovies.fr/resultat_recherche.php?cherche="
		self.translated_url_search	= "http://www.cinemovies.fr/resultat_recherche.php?cherche="

	def search(self,parent_window):
		self.open_search(parent_window)
		self.sub_search()
		return self.page

	def sub_search(self):
		self.page = gutils.trim(self.page,"height=\"6\">Films</td>", "height=\"6\">News</td>")

	def get_searches(self):
		elements = string.split(self.page,"</tr>  <tr>")
		self.number_results = elements[-1]

		if (elements[0]<>''):
			for element in elements:
				self.ids.append(gutils.trim(element,"?IDfilm=","\" class=\"arial"))
				self.titles.append(gutils.convert_entities(gutils.strip_tags(gutils.trim(element,"12black3\">","</font><br>"))))
		else:
			self.number_results = 0



# -*- coding: UTF-8 -*-

__revision__ = '$Id: main_treeview.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import os
import gtk

def treeview_clicked(self):
	if self.initialized is False:
		return False
	if self.total:
		treeselection = self.widgets['treeview'].get_selection()
		(tmp_model, tmp_iter) = treeselection.get_selected()
		if tmp_iter is None:
			self.debug.show('Treeview: no selection')
			return False
		number = tmp_model.get_value(tmp_iter,0)
		movie = self.db.Movie.get_by(number=number)
		movie.refresh() # loan data can be obsolete in cache
		if movie is None:
			self.debug.show("Treeview: movie doesn't exists (number=%s)"%number)
		set_details(self, movie)
	else:
		set_details(self, {})

def set_details(self, item=None):#{{{
	from loan import get_loan_info, get_loan_history
	if item is None:
		item = {}
	if item.has_key('movie_id') and item['movie_id']:
		self._movie_id = item['movie_id']
	else:
		self._movie_id = None
	w = self.widgets['movie']

	if item.has_key('number') and item['number']:
		w['number'].set_text(str(int(item['number'])))
	else:
		w['number'].set_text('')
	if item.has_key('title') and item['title']:
		w['title'].set_markup("<b><span size='large'>%s</span></b>" % gutils.html_encode(item['title']))
	else:
		w['title'].set_text('')
	if item.has_key('o_title') and item['o_title']:
		w['o_title'].set_markup("<span size='medium'><i>%s</i></span>" % gutils.html_encode(item['o_title']))
	else:
		w['o_title'].set_text('')
	if item.has_key('director') and item['director']:
		w['director'].set_markup("<i>%s</i>" % gutils.html_encode(item['director']))
	else:
		w['director'].set_text('')
	if item.has_key('plot') and item['plot']:
		w['plot'].set_text(str(item['plot']))
	else:
		w['plot'].set_text('')
	if item.has_key('year') and item['year']:
		w['year'].set_text(str(item['year']))
	else:
		w['year'].set_text('')
	if item.has_key('runtime') and item['runtime']:
		w['runtime'].set_text(str(int(item['runtime'])))
	else:
		w['runtime'].set_text('x')
	if item.has_key('cast') and item['cast']:
		w['cast'].set_text(str(item['cast']))
	else:
		w['cast'].set_text('')
	if item.has_key('country') and item['country']:
		w['country'].set_markup("<i>%s</i>" % gutils.html_encode(item['country']))
	else:
		w['country'].set_text('')
	if item.has_key('genre') and item['genre']:
		w['genre'].set_markup("<i>%s</i>" % gutils.html_encode(item['genre']))
	else:
		w['genre'].set_text('')
	if item.has_key('cond') and item['cond']:
		if str(item['cond']) in [ str(i) for i in range(len(self._conditions)) ]:
			w['condition'].set_markup("<i>%s</i>" % self._conditions[item['cond']])
		else:
			w['condition'].set_text('')
			self.debug.show("Wrong value in 'condition' field (movie_id=%s, cond=%s)" % (item['movie_id'], item['cond']))
	else:
		w['condition'].set_text('')
	if item.has_key('region') and item['region']:
		if str(item['region']) in [ str(i) for i in range(len(self._regions)) ]:
			w['region'].set_markup("<i>%s</i>" % gutils.html_encode(item['region']))
			if int(item['region']) < 9:
				self.widgets['tooltips'].set_tip(w['region'], self._regions[int(item['region'])])
		else:
			self.debug.show("Wrong value in 'region' field (movie_id=%s, region=%s)" % (item['movie_id'], item['region']))
			w['region'].set_text('')
			self.widgets['tooltips'].set_tip(w['region'], self._regions[0]) # N/A
	else:
		w['region'].set_text('')
		self.widgets['tooltips'].set_tip(w['region'], self._regions[0]) # N/A
	if item.has_key('layers') and item['layers']:
		if str(item['layers']) in [ str(i) for i in range(len(self._layers)) ]:
			w['layers'].set_markup("<i>%s</i>" % self._layers[item['layers']])
		else:
			self.debug.show("Wrong value in 'layers' field (movie_id=%s, layers=%s)" % (item['movie_id'], item['layers']))
			w['layers'].set_text('')
	else:
		w['layers'].set_text('')
	if item.has_key('color') and item['color']:
		if str(item['color']) in [ str(i) for i in range(len(self._colors)) ]:
			w['color'].set_markup("<i>%s</i>" % self._colors[item['color']])
		else:
			self.debug.show("Wrong value in 'color' field (movie_id=%s, color=%s)" % (item['movie_id'], item['color']))
			w['color'].set_markup('')
	else:
		w['color'].set_markup('')
	if item.has_key('classification') and item['classification']:
		w['classification'].set_markup("<i>%s</i>" % gutils.html_encode(item['classification']))
	else:
		w['classification'].set_text('')
	if item.has_key('studio') and item['studio']:
		w['studio'].set_markup("<i>%s</i>" % gutils.html_encode(item['studio']))
	else:
		w['studio'].set_text('')
	if item.has_key('o_site') and item['o_site']:
		self._o_site_url = str(item['o_site'])
		w['go_o_site_button'].set_sensitive(True)
	else:
		self._o_site_url = None
		w['go_o_site_button'].set_sensitive(False)
	if item.has_key('site') and item['site']:
		self._site_url = str(item['site'])
		w['go_site_button'].set_sensitive(True)
	else:
		self._site_url = None
		w['go_site_button'].set_sensitive(False)
	if item.has_key('trailer') and item['trailer']:
		self._trailer_url = str(item.trailer)
		w['go_trailer_button'].set_sensitive(True)
	else:
		self._trailer_url = None
		w['go_trailer_button'].set_sensitive(False)
	if item.has_key('seen') and item['seen'] == True:
		w['seen_icon'].set_from_file(os.path.join(self.locations['images'], 'seen.png'))
	else:
		w['seen_icon'].set_from_file(os.path.join(self.locations['images'], 'unseen.png'))
	if item.has_key('notes') and item['notes']:
		w['notes'].set_text(str(item.notes))
	else:
		w['notes'].set_text('')
	tmp = ''
	if item.has_key('media_num') and item['media_num']:
		tmp = str(item.media_num)
	else:
		tmp = '0'
	if item.has_key('medium_id') and item['medium_id']:
		if item.medium is not None:
			tmp += ' x ' + item.medium.name
		else:
			pass
	w['medium'].set_markup("<i>%s</i>" % gutils.html_encode(tmp))
	if item.has_key('vcodec_id'):
		if item.vcodec is not None:
			w['vcodec'].set_markup("<i>%s</i>" % gutils.html_encode(item.vcodec.name))
		else:
			w['vcodec'].set_text('')
	else:
		w['vcodec'].set_text('')

	# poster
	if item.has_key('image') and item['image']:
		tmp_dest = self.locations['posters']
		tmp_img = os.path.join(tmp_dest, "m_%s.jpg"%item['image'])
		tmp_img2 = os.path.join(tmp_dest, "%s.jpg"%item['image'])
		if os.path.isfile(tmp_img2):
			image_path = tmp_img
			self.widgets['add']['delete_poster'].set_sensitive(True)
			self.widgets['menu']['delete_poster'].set_sensitive(True)
			w['picture_button'].set_sensitive(True)
		else:
			image_path = os.path.join(self.locations['images'], 'default.png')
			self.widgets['add']['delete_poster'].set_sensitive(False)
			self.widgets['menu']['delete_poster'].set_sensitive(False)
			w['picture_button'].set_sensitive(False)
		# lets see if we have a scaled down medium image already created
		if not os.path.isfile(image_path):
			# if not, lets make one for future use :D
			original_image = os.path.join(tmp_dest, "%s.jpg"%item.image)
			if os.path.isfile(original_image):
				gutils.make_medium_image(self, "%s.jpg"%item.image)
	else:
		image_path = os.path.join(self.locations['images'], 'default.png')
		w['picture_button'].set_sensitive(False)
	w['picture'].set_from_file(image_path)
	# ratig
	rimage = int(self.config.get('rating_image', 0))
	if rimage:
		prefix = ''
	else:
		prefix = 'meter'
	if item.has_key('rating') and item['rating']:
		rating_file = "%s/%s0%d.png" % (self.locations['images'], prefix, item['rating'])
	else:
		rating_file = "%s/%s0%d.png" % (self.locations['images'], prefix, 0)
	handler = w['image_rating'].set_from_pixbuf(gtk.gdk.pixbuf_new_from_file(rating_file))
	gutils.garbage(handler)

	# check loan status and adjust buttons and history box
	if item.has_key('loaned') and item['loaned'] == True:
		self.widgets['popups']['loan'].set_sensitive(False)
		self.widgets['popups']['email'].set_sensitive(True)
		self.widgets['popups']['return'].set_sensitive(True)
		self.widgets['menu']['loan'].set_sensitive(False)
		self.widgets['menu']['email'].set_sensitive(True)
		self.widgets['menu']['return'].set_sensitive(True)
		w['loan_button'].set_sensitive(False)
		w['email_reminder_button'].set_sensitive(True)
		w['return_button'].set_sensitive(True)
		
		data_loan = get_loan_info(self.db, collection_id=item['collection_id'], volume_id=item['volume_id'], movie_id=item['movie_id'])
		if data_loan is None:
			item.loaned = False
		else:
			data_person = self.db.Person.get_by(person_id=data_loan.person.person_id)
			self.person_name = str(data_person.name)
			self.person_email = str(data_person.email)
			self.loan_date = str(data_loan.date)
			w['loan_info'].set_use_markup(False)
			w['loan_info'].set_label(_("This movie has been loaned to ") + self.person_name + _(" on ") + self.loan_date[:10])
	if item.has_key('loaned') and item['loaned'] != True: # "loaned" status can be changed above, so don't use "else:" in this line
		self.widgets['popups']['loan'].set_sensitive(True)
		self.widgets['popups']['email'].set_sensitive(False)
		self.widgets['popups']['return'].set_sensitive(False)
		self.widgets['menu']['loan'].set_sensitive(True)
		self.widgets['menu']['email'].set_sensitive(False)
		self.widgets['menu']['return'].set_sensitive(False)
		w['return_button'].set_sensitive(False)
		w['email_reminder_button'].set_sensitive(False)
		w['loan_button'].set_sensitive(True)
		w['loan_info'].set_markup("<b>%s</b>" % _("Movie not loaned"))

	# loan history	
	self.loans_treemodel.clear()
	if item.has_key('collection_id') or item.has_key('volume_id') or item.has_key('movie_id'):
		loans = get_loan_history(self.db, collection_id=item['collection_id'], volume_id=item['volume_id'], movie_id=item['movie_id'])
		for loan in loans:
			myiter = self.loans_treemodel.append(None)
			self.loans_treemodel.set_value(myiter, 0,'%s' % str(loan.date)[:10])
			if loan.return_date and  loan.return_date != '':
				self.loans_treemodel.set_value(myiter, 1, str(loan.return_date)[:10])
			else:
				self.loans_treemodel.set_value(myiter, 1, "---")
			person = self.db.Person.get_by(person_id=loan.person.person_id)
			self.loans_treemodel.set_value(myiter, 2, person.name)

	# volumes/collections
	if item.has_key('volume_id') and item['volume_id']>0:
		if item.has_key('volume') and item['volume']:
			w['volume'].set_markup("<b>%s</b>" % gutils.html_encode(item['volume'].name))
			w['show_volume_button'].set_sensitive(True)
		else:
			w['volume'].set_text('')
			w['show_volume_button'].set_sensitive(False)
	else:
			w['volume'].set_text('')
			w['show_volume_button'].set_sensitive(False)
	if item.has_key('collection_id') and item['collection_id']>0:
		if item.has_key('collection') and item['collection']:
			w['collection'].set_markup("<b>%s</b>" % gutils.html_encode(item['collection'].name))
			w['show_collection_button'].set_sensitive(True)
		else:
			w['collection'].set_text('')
			w['show_collection_button'].set_sensitive(False)
	else:
		w['collection'].set_text('')
		w['show_collection_button'].set_sensitive(False)

	# languages
	for i in w['audio_vbox'].get_children():
		i.destroy()
	for i in w['subtitle_vbox'].get_children():
		i.destroy()
	if item.has_key('languages') and len(item['languages'])>0:
		for i in item['languages']:
			if i.type == 3: # subtitles
				if i.subformat:
					tmp = "%s - %s" % (i.language.name, i.subformat.name)
				else:
					tmp = "%s" % i.language.name
				w['subtitle_vbox'].pack_start(gtk.Label(tmp))
			else:
				language = i.language.name
				if i.type is not None and len(self._lang_types[i.type])>0:
					language += " <i>%s</i>" % self._lang_types[i.type]
				tmp = ''
				if i.achannel:
					tmp = i.achannel.name
				if i.acodec:
					if len(tmp)>0:
						tmp += ", %s" % i.acodec.name
					else:
						tmp = i.acodec.name
				if len(tmp)>0:
					tmp = "%s (%s)" % (language, tmp)
				else:
					tmp = language
				widget = gtk.Label(tmp)
				widget.set_use_markup(True)
				w['audio_vbox'].pack_start(widget)
	w['audio_vbox'].show_all()
	w['subtitle_vbox'].show_all()
	#tags
	if item.has_key('tags'):
		tmp = ''
		for tag in item['tags']:
			tmp += "%s, " % tag.name
		tmp = tmp[:-2] # cut last comma
		w['tags'].set_text(tmp)
	#}}}
	
def populate(self, movies=None, where=None):#{{{
	if self.initialized is False:
		return False
	from sqlalchemy import Select, desc
	
	if movies is None:
		movies = Select([self.db.Movie.c.number,
			self.db.Movie.c.o_title, self.db.Movie.c.title,
			self.db.Movie.c.director, self.db.Movie.c.image,
			self.db.Movie.c.genre, self.db.Movie.c.seen,
			self.db.Movie.c.year, self.db.Movie.c.runtime,
			self.db.Movie.c.rating])

	if isinstance(movies, Select):
		if not where: # because of possible 'seen', 'loaned', 'collection_id' in where
			# seen / loaned
			loaned_only = self.widgets['menu']['loaned_movies'].get_active()
			not_seen_only = self.widgets['menu']['not_seen_movies'].get_active()
			if loaned_only:
				movies.append_whereclause(self.db.Movie.c.loaned==True)
			if not_seen_only:
				movies.append_whereclause(self.db.Movie.c.seen==False)
			# collection
			pos = self.widgets['filter']['collection'].get_active()
			if pos >= 0:
				col_id = self.collection_combo_ids[pos]
				if col_id > 0:
					movies.append_whereclause(self.db.Movie.c.collection_id==col_id)
			# volume
			pos = self.widgets['filter']['volume'].get_active()
			if pos >= 0:
				vol_id = self.volume_combo_ids[pos]
				if vol_id > 0:
					movies.append_whereclause(self.db.Movie.c.volume_id==vol_id)
			# loaned to
			pos = self.widgets['filter']['loanedto'].get_active()
			if pos >= 0:
				per_id = self.loanedto_combo_ids[pos]
				if per_id > 0:
					from sqlalchemy import join, exists, and_
					loan_exists = exists([self.db.Loan.c.movie_id], \
						and_(self.db.Movie.c.movie_id==self.db.Loan.c.movie_id, self.db.Loan.c.person_id==per_id, self.db.Loan.c.return_date==None))
					movies.append_whereclause(loan_exists)
					#loan_join = join(self.db.metadata.tables['movies'], \
					#	self.db.metadata.tables['loans'], \
					#	self.db.metadata.tables['movies'].c.movie_id==self.db.metadata.tables['loans'].c.movie_id)
					#movies = movies.select_from(loan_join)
			# tag
			pos = self.widgets['filter']['tag'].get_active()
			if pos >= 0:
				tag_id = self.bytag_combo_ids[pos]
				if tag_id > 0:
					from sqlalchemy import join, exists, and_
					tag_exists = exists([self.db.MovieTag.c.movie_id], \
						and_(self.db.Movie.c.movie_id==self.db.MovieTag.c.movie_id, self.db.MovieTag.c.tag_id==tag_id))
					movies.append_whereclause(tag_exists)
		
		# select sort column
		sort_column_name = self.config.get('sortby', 'number', section='mainlist')
		sort_reverse = self.config.get('sortby_reverse', False, section='mainlist')
		for i in sort_column_name.split(','):
			if self.db.Movie.c.has_key(i):
				if sort_reverse:
					movies.order_by_clause.append(desc(self.db.Movie.c[i]))
				else:
					movies.order_by_clause.append(self.db.Movie.c[i])
		
		# additional whereclause (volume_id, collection_id, ...)
		if where:
			for i in where:
				if self.db.Movie.c.has_key(i):
					movies.append_whereclause(self.db.Movie.c[i]==where[i])
		movies = movies.execute().fetchall()

	self.total = len(movies)
	# disable refreshing while inserting
	self.widgets['treeview'].freeze_child_notify()
	self.widgets['treeview'].set_model(None)

	# save user sort column
	sort_column_id, order = self.treemodel.get_sort_column_id()

	# new treemodel (faster and prevents some problems)
	self.treemodel = gtk.TreeStore(str, gtk.gdk.Pixbuf, str, str, str, str, bool, str, str, int)

	# check preferences to hide or show columns
	if self.config.get('number', True, 'mainlist') == True:
		self.number_column.set_visible(True)
	else:
		self.number_column.set_visible(False)
	if self.config.get('otitle', True, 'mainlist') == True:
		self.otitle_column.set_visible(True)
	else:
		self.otitle_column.set_visible(False)
	if self.config.get('title', True, 'mainlist') == True:
		self.title_column.set_visible(True)
	else:
		self.title_column.set_visible(False)
	if self.config.get('director', True, 'mainlist') == True:
		self.director_column.set_visible(True)
	else:
		self.director_column.set_visible(False)
	if self.config.get('image', True, 'mainlist') == True:
		self.image_column.set_visible(True)
	else:
		self.image_column.set_visible(False)
	if self.config.get('genre', True, 'mainlist') == True:
		self.genre_column.set_visible(True)
	else:
		self.genre_column.set_visible(False)
	if self.config.get('seen', True, 'mainlist') == True:
		self.seen_column.set_visible(True)
	else:
		self.seen_column.set_visible(False)
	if self.config.get('year', True, 'mainlist') == True:
		self.year_column.set_visible(True)
	else:
		self.year_column.set_visible(False)
	if self.config.get('runtime', True, 'mainlist') == True:
		self.runtime_column.set_visible(True)
	else:
		self.runtime_column.set_visible(False)
	if self.config.get('rating', True, 'mainlist') == True:
		self.rating_column.set_visible(True)
	else:
		self.rating_column.set_visible(False)
		
	for movie in movies:
		myiter = self.treemodel.append(None)
		
		self.treemodel.set_value(myiter,0,'%004d' % int(movie.number))

		if self.config.get('image', True, section='mainlist') == True:
			tmp_dest = self.locations['posters']
			tmp_img = os.path.join(tmp_dest, "t_%s.jpg" % str(movie.image))
			if movie.image and os.path.isfile(tmp_img):
				image_path = tmp_img
			else:
				image_path = os.path.join(self.locations['images'], 'default_thumbnail.png')
			# lets see if we have a scaled down thumbnail already created
			if os.path.isfile(os.path.join(tmp_dest, "t_%s.jpg" % str(movie.image))):
				pass
			else:
				# if not, lets make one for future use :D
				original_image = os.path.join(tmp_dest, "%s.jpg" % movie.image)
				if os.path.isfile(original_image):
					gutils.make_thumbnail(self, "%s.jpg" % movie.image)
				else:
					self.Image.set_from_file("%s/default_thumbnail.png" % self.locations['images'])
					pixbuf = self.Image.get_pixbuf()
			self.Image.set_from_file(image_path)
			pixbuf = self.Image.get_pixbuf()
			self.treemodel.set_value(myiter, 1, pixbuf)
		self.treemodel.set_value(myiter,2,movie.o_title)
		self.treemodel.set_value(myiter,3,movie.title)
		self.treemodel.set_value(myiter,4,movie.director)
		self.treemodel.set_value(myiter,5,movie.genre)
		self.treemodel.set_value(myiter,6,movie.seen)
		if movie.year is not None and isinstance(movie.year, int):
			self.treemodel.set_value(myiter,7,movie.year)
		if movie.runtime is not None and isinstance(movie.runtime, int):
			self.treemodel.set_value(myiter,8, '%003d' % movie.runtime + _(' min'))
		if movie.rating is not None and isinstance(movie.rating, int):
			self.treemodel.set_value(myiter,9,movie.rating)
		
	# restore user sort column
	if sort_column_id is not None:
		self.treemodel.set_sort_column_id(sort_column_id, gtk.SORT_ASCENDING)
	
	# add new treemodel and allow refreshs again
	self.widgets['treeview'].set_model(self.treemodel)
	self.widgets['treeview'].thaw_child_notify()
	self.widgets['treeview'].set_cursor_on_cell(0)
	self.count_statusbar()
#}}}

# vim: fdm=marker



# -*- coding: utf-8 -*-

__revision__ = '$Id: PluginMovieStopklatka.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2005-2008 Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils, movie
import string, re

plugin_name         = 'Stopklatka'
plugin_description  = 'Internetowy Serwis Filmowy'
plugin_url          = 'www.stopklatka.pl'
plugin_language     = _('Polish')
plugin_author       = 'Piotr Ożarowski'
plugin_author_email = '<ozarow+griffith@gmail.com>'
plugin_version      = '1.9'

class Plugin(movie.Movie):
	IMAGE_PATTERN = re.compile('(http://img.stopklatka.pl/film/.*?)"')

	def __init__(self, id):
		self.movie_id = id
		self.url = "http://www.stopklatka.pl/film/film.asp?fi=%s" % str(self.movie_id)
		self.encode = 'iso-8859-2' # with some cp-1250 data (sic!)

	def initialize(self):
		self.page = self.page.replace('\x9c','ś')
		self.page = self.page.replace('š','ą')

	def get_image(self):
		image = self.IMAGE_PATTERN.findall(self.page)
		if len(image):
			self.image_url = image[0]

	def get_o_title(self):
		self.o_title = gutils.trim(self.page, '<h2> (', ')</h2>')
		if self.o_title == '':
			self.o_title = self.get_title(True)

	def get_title(self, ret=False):
		data = gutils.trim(self.page, '<h1>', '</h1>')
		if ret is True:
			return data
		else:
			self.title = data

	def get_director(self):
		self.director = gutils.trim(self.page, '>re\xbfyseria:<', '</td></tr>')
		self.director = gutils.after(self.director, '>')

	def get_plot(self):
		self.plot = gutils.trim(self.page, '<p>', '</p>')
		self.plot = gutils.before(self.plot, '<b>Wi\xEAcej ')

	def get_year(self):
		self.year = gutils.trim(self.page, '>rok produkcji:<', '</span>')
		self.year = gutils.after(self.year, '>')

	def get_runtime(self):
		self.runtime = gutils.trim(self.page, 'trwania:<', ' min<')
		self.runtime = gutils.after(self.runtime, '>')

	def get_genre(self):
		self.genre = gutils.trim(self.page, '>gatunek:<', '</span>')
		self.genre = gutils.after(self.genre, '>')

	def get_cast(self):
		self.cast = gutils.trim(self.page, '>obsada:<', '</td></tr>')
		self.cast = gutils.after(self.cast, '>')
		self.cast = string.replace(self.cast, ', ', "\n")
		self.cast = gutils.before(self.cast, '<b>Wi\xEAcej ')

	def get_classification(self):
		self.classification = ''

	def get_studio(self):
		self.studio = ""

	def get_o_site(self):
		self.o_site = gutils.trim(self.page,">strona oficjalna:<"," target=_blank")
		self.o_site = gutils.after(self.o_site,"href=")

	def get_site(self):
		self.site = self.url

	def get_trailer(self):
		self.trailer = "http://www.stopklatka.pl/film/film.asp?fi=" + self.movie_id + "&sekcja=mmedia"

	def get_country(self):
		self.country = gutils.trim(self.page, '>kraj:<', '</span>')
		self.country = gutils.after(self.country, '>')

	def get_rating(self):
		self.rating = '0'

	def get_notes(self):
		self.notes = ''

class SearchPlugin(movie.SearchMovie):
	def __init__(self):
		self.encode='iso-8859-2'
		self.original_url_search	= "http://www.stopklatka.pl/szukaj/szukaj.asp?kategoria=film&szukaj="
		self.translated_url_search	= "http://www.stopklatka.pl/szukaj/szukaj.asp?kategoria=film&szukaj="

	def search(self,parent_window):
		self.open_search(parent_window)
		self.page = gutils.trim(self.page, '>Wyniki poszukiwania frazy:', '</div>');
		self.page = self.page.replace('\x9c','ś')
		self.page = self.page.replace('š','ą')
		return self.page

	def get_searches(self):
		elements = re.findall("""/film/film.asp\?fi=(\d+)">.*?searchTitle\s*textB">(.*?)</span""", self.page)
		self.number_results = len(elements)

		for element in elements:
			self.ids.append(element[0])
			self.titles.append(element[1])



# -*- coding: iso-8859-15 -*-

__revision__ = '$Id: PluginMovieFilmAffinity.py 389 2006-07-29 18:43:35Z piotrek $'

# Copyright (c) 2006 Pedro D. Sánchez
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie
import string

plugin_name		= 'FilmAffinity'
plugin_description	= 'Base de Datos de Peliculas'
plugin_url		= 'www.filmaffinity.com'
plugin_language		= _('Spanish')
plugin_author		= 'Pedro D. Sánchez'
plugin_author_email	= '<pedrodav@gmail.com>'
plugin_version		= '0.2'

class Plugin(movie.Movie):
	def __init__(self, id):
		self.encode='iso-8859-15'
		self.movie_id = id
		self.url = "http://www.filmaffinity.com/es/film%s.html" % str(self.movie_id)

	def get_image(self):
		tmp = string.find(self.page, '<img src="http://www.filmaffinity.com/imgs/movies/')
		if tmp == -1:
			self.image_url = ''
		else:
			self.image_url = gutils.trim(self.page[tmp-1:], 'src="', '"')

	def get_o_title(self):
		self.o_title = gutils.trim(self.page, '<b>TITULO ORIGINAL</b></td>', '</b></td>')
		self.o_title = gutils.after(self.o_title, '<b>')

	def get_title(self):
		self.title = gutils.trim(self.page, '<img src="http://www.filmaffinity.com/images/movie.gif" border="0"> ', '</span>')

	def get_director(self):
		self.director = gutils.trim(self.page,'<b>DIRECTOR</b></td>', '</td>')

	def get_plot(self):
		self.plot = gutils.trim(self.page, '<b>GÉNERO Y CRÍTICA</b>', '<br />')
		if self.plot == '':
			self.plot = gutils.trim(self.page, '<b>G&Eacute;NERO Y CR&Iacute;TICA</b>', '<br />')
		self.plot = gutils.after(self.plot, '<td valign="top">')
		self.plot = gutils.after(self.plot, '/')
		self.plot = string.replace(self.plot, ' SINOPSIS: ', '')
		self.plot = string.replace(self.plot, ' SINOPSIS:', '')
		self.plot = string.replace(self.plot, 'SINOPSIS: ', '')
		self.plot = string.replace(self.plot, 'SINOPSIS:', '')
		self.plot = string.replace(self.plot, ' (FILMAFFINITY)', '')
		self.plot = string.replace(self.plot, '(FILMAFFINITY)', '')

	def get_year(self):
		self.year = gutils.trim(self.page, '<b>AÑO</b></td>', '</td>')
		self.year = gutils.after(self.year, '<td >')

	def get_runtime(self):
		self.runtime = gutils.trim(self.page, '<b>DURACIÓN</b></td>', ' min.</td>')
		if self.runtime == '':
			self.runtime = gutils.trim(self.page, '<b>DURACI&Oacute;N</b></td>', ' min.</td>')
		self.runtime = gutils.after(self.runtime[-10:], '<td>')

	def get_genre(self):
		self.genre = gutils.trim(self.page, '<b>GÉNERO Y CRÍTICA</b>', '<br />')
		if self.genre == '':
			self.genre = gutils.trim(self.page, '<b>G&Eacute;NERO Y CR&Iacute;TICA</b>', '<br />')
		self.genre = gutils.trim(self.genre, '<td valign="top">', '/')
		self.genre = string.replace(self.genre, '.', " /")

	def get_cast(self):
		self.cast = ''
		self.cast = gutils.trim(self.page, '<b>REPARTO</b></td>', '</td>')
		self.cast = string.replace(self.cast, '</a>,', '\n')
		self.cast = string.strip(gutils.strip_tags(self.cast))
		self.cast = string.replace(self.cast, '  ', '')

	def get_classification(self):
		self.classification = ''

	def get_studio(self):
		self.studio = gutils.trim(self.page, '<b>PRODUCTORA</b></td>', '</td>')
		self.studio = gutils.after(self.studio, '<td  >')

	def get_o_site(self):
		self.o_site = gutils.trim(self.page, '<b>WEB OFICIAL</b></td>', '</a>')
		self.o_site = gutils.after(self.o_site, '">')

	def get_site(self):
		self.site = "http://www.filmaffinity.com/es/film%s.html" % str(self.movie_id)

	def get_trailer(self):
		self.trailer = ''

	def get_country(self):
		self.country = gutils.trim(self.page, '<b>PAÍS</b></td>', '</td>')
		self.country = gutils.trim(self.country, 'alt="', '"')

	def get_rating(self):
		self.rating = gutils.trim(self.page, '<tr><td align="center" style="color:#990000; font-size:22px; font-weight: bold;">', '</td></tr>')
		if self.rating:
			self.rating = str(float(gutils.clean(string.replace(self.rating, ',', '.'))))

class SearchPlugin(movie.SearchMovie):

	def __init__(self):
		self.original_url_search	= 'http://www.filmaffinity.com/es/search.php?stype=title&stext='
		self.translated_url_search	= 'http://www.filmaffinity.com/es/search.php?stype=title&stext='
		self.encode = 'iso-8859-15'

	def search(self,parent_window):
		self.open_search(parent_window)
		auxPage = self.page
		self.sub_search()
		if self.page <> '':
			return self.page
		auxPage = gutils.trim(auxPage, '<b>TU CRÍTICA</b></div>', '</a>')
		self.page = gutils.trim(auxPage, 'movie_id=', '">')
		return self.page

	def sub_search(self):
		self.page = gutils.trim(self.page, 'Resultados por título</span>', '<br>')
		#self.page = gutils.after(self.page, '</td></tr><tr><td><b>')
		#self.page = self.page.decode('iso-8859-15')

	def get_searches(self):
		if len(self.page) < 20:	# immidietly redirection to movie page
			self.number_results = 1
			self.ids.append(self.page)
			self.titles.append(self.url)
		else:			# multiple matches
			elements = string.split(self.page, '</a></b>')

			if (elements[0]<>''):
				for element in elements[:-1]:
					self.ids.append(gutils.trim(element, '<b><a href="/es/film','.html'))
					title = gutils.after(element, '<b><a href="/es/film')
					self.titles.append(gutils.strip_tags(gutils.convert_entities(gutils.after(title, '>'))))



# -*- coding: UTF-8 -*-

__revision__ = '$Id$'

# Written by Christian Sagmueller <christian@sagmueller.net>
# based on PluginMovieIMDB.py, Copyright (c) 2005 Vasco Nunes
# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie,string,re

plugin_name = "OFDb"
plugin_description = "Online-Filmdatenbank"
plugin_url = "www.ofdb.de"
plugin_language = _("German")
plugin_author = "Christian Sagmueller, Jessica Katharina Parth"
plugin_author_email = "Jessica.K.P@women-at-work.org"
plugin_version = "0.9"

class Plugin(movie.Movie):
	def __init__(self, id):
		self.encode='utf-8'
		self.movie_id = id
		self.url = "http://www.ofdb.de/%s" % str(self.movie_id)

	def initialize(self):
		# OFDb didn't provide the runtime, studio and classification but it provide a link to the german imdb entry
		# lets use the imdb page, why not
		imdb_nr = gutils.trim(self.page, 'http://german.imdb.com/Title?', '"')
		if imdb_nr != '':
			self.imdb_page = self.open_page(url='http://german.imdb.com/Title?' + imdb_nr)
		else:
			self.imdb_page = ''

	def get_image(self):
		self.image_url = "http://img.ofdb.de/film/" + gutils.trim(self.page, 'img src="http://img.ofdb.de/film/', '"' )
		
	def get_o_title(self):
		self.o_title = gutils.clean(gutils.trim(self.page, 'Originaltitel:', '</tr>'))
		if self.o_title == '':
			self.o_title = string.replace(self.o_title, '&nbsp;', '' )

	def get_title(self):
		self.title = gutils.trim(self.page,'size="3"><b>','<')

	def get_director(self):
		self.director = gutils.trim(self.page,"Regie:","</a><br>")

	def get_plot(self):
		storyid = self.regextrim(self.page, '<a href="plot/', '(">|[&])')
		if not storyid is None:
			story_page = self.open_page(url="http://www.ofdb.de/plot/%s" % (storyid))
		self.plot = gutils.trim(story_page, "</b><br><br>","</")

	def get_year(self):
		self.year = gutils.trim(self.page,"Erscheinungsjahr:","</a>")
		self.year = gutils.strip_tags(self.year)

	def get_runtime(self):
		# from imdb
		self.runtime = gutils.trim(self.imdb_page, '<h5>L&auml;nge:</h5>', ' Min')

	def get_genre(self):
		self.genre = gutils.trim(self.page,"Genre(s):","</table>")
		self.genre = string.replace(self.genre, "<br>", ", ")
		self.genre = gutils.strip_tags(self.genre)
		self.genre = string.replace(self.genre, "/", ", ")
		self.genre = gutils.clean(self.genre)
		self.genre = self.genre[0:-1]

	def get_cast(self):
		self.cast = ''
		movie_id_elements = string.split(self.movie_id, ',')
		movie_id_elements[0] = string.replace(movie_id_elements[0], "film/", "")
		cast_page = self.open_page(url="http://www.ofdb.de/view.php?page=film_detail&fid=%s" % str(movie_id_elements[0]) )
		self.cast = gutils.trim(cast_page, 'Darsteller</i>', '</table>')
		self.cast = re.sub('(\n|\t|&nbsp;)', '', self.cast)
		self.cast = string.replace(self.cast, '\t', '')
		self.cast = string.replace(self.cast, 'class="Daten">', '>\n')
		self.cast = string.strip(gutils.strip_tags(self.cast))
		self.cast = string.replace(self.cast, '... ', _(' as '))
		self.cast = gutils.clean(self.cast)

	def get_classification(self):
		# from imdb
		self.classification = gutils.trim(gutils.trim(self.imdb_page, 'Altersfreigabe:', '</div>'), 'Germany:', '&')

	def get_studio(self):
		# from imdb
		self.studio = gutils.trim(self.imdb_page, '<h5>Firma:</h5>', '</a>')

	def get_o_site(self):
		self.o_site = ""

	def get_site(self):
		self.site = self.url

	def get_trailer(self):
		self.trailer = ""

	def get_country(self):
		self.country = gutils.trim(self.page,"Herstellungsland:","</a>")

	def get_rating(self):
		self.rating = gutils.trim(self.page,"<br>Note: ","&nbsp;")
		if self.rating == '':
			self.rating = "0"
		self.rating = str(round(float(self.rating)))

	def regextrim(self,text,key1,key2):
		obj = re.search(key1, text)
		if obj is None:
			return ''
		else:
			p1 = obj.end()
		obj = re.search(key2, text[p1:])
		if obj is None:
			return ''
		else:
			p2 = p1 + obj.start()
		return text[p1:p2]

class SearchPlugin(movie.SearchMovie):
	def __init__(self):
		self.original_url_search   = "http://www.ofdb.de/view.php?page=suchergebnis&Kat=OTitel&SText="
		self.translated_url_search = "http://www.ofdb.de/view.php?page=suchergebnis&Kat=DTitel&SText="
		self.encode='utf-8'
		self.remove_accents = False

	def search(self,parent_window):
		self.open_search(parent_window)
		self.page = gutils.trim(self.page,"</b><br><br>", "<br><br><br>");
		self.page = string.replace( self.page, "'", '"' )
		self.page = string.replace( self.page, '<font size="1">', '' )
		self.page = string.replace( self.page, '</font>', '' )
		return self.page

	def get_searches(self):
		elements = string.split(self.page,"<br>")

		if (elements[0]<>''):
			for element in elements:
				elementid = gutils.trim(element,'<a href="','"')
				if not elementid is None and not elementid == '':
					self.ids.append(elementid)
					elementname = gutils.clean(element)
					p1 = string.find(elementname, '>')
					if p1 == -1:
						self.titles.append(elementname)
					else:
						self.titles.append(elementname[p1+1:])

#
# Plugin Test
#
class SearchPluginTest(SearchPlugin):
	#
	# Configuration for automated tests:
	# dict { movie_id -> [ expected result count for original url, expected result count for translated url ] }
	#
	test_configuration = {
		'Rocky Balboa'			: [ 1, 1 ],
		'Arahan'				: [ 3, 2 ],
		'glückliches'			: [ 4, 2 ]
	}

class PluginTest:
	#
	# Configuration for automated tests:
	# dict { movie_id -> dict { arribute -> value } }
	#
	# value: * True/False if attribute only should be tested for any value
	#        * or the expected value
	#
	test_configuration = {
		'film/103013,Rocky%20Balboa' : { 
			'title' 			: 'Rocky Balboa',
			'o_title' 			: 'Rocky Balboa',
			'director'			: 'Sylvester Stallone',
			'plot' 				: True,
			'cast'				: 'Sylvester Stallone' + _(' as ') + 'Rocky Balboa\n\
Burt Young' + _(' as ') + 'Paulie\n\
Milo Ventimiglia' + _(' as ') + 'Robert Jr.\n\
Geraldine Hughes' + (' as ') + 'Marie\n\
James Francis Kelly III\n\
Tony Burton\n\
A.J. Benza\n\
Henry G. Sanders\n\
Antonio Tarver' + (' as ') + 'Mason \'The Line\' Dixon\n\
Pedro Lovell\n\
Ana Gerena\n\
Angela Boyd\n\
Louis Giansante\n\
Maureen Schilling\n\
Carter Mitchell\n\
Vinod Kumar\n\
Tobias Segal\n\
Tim Carr\n\
Paul Dion Monte\n\
Kevin King Templeton\n\
Robert Michael Kelly\n\
Don Sherman\n\
Nick Baker\n\
Rick Buchborn\n\
Stu Nahan\n\
Gary Compton\n\
Jody Giambelluca\n\
Frank Stallone\n\
Fran Pultro\n\
Michael Buffer as Ring Announcer\n\
Jack Lazzarado\n\
Marc Ratner\n\
Anthony Lato Jr.\n\
Yahya\n\
Gunnar Peterson\n\
Bernard Fernández\n\
Bert Randolph Sugar\n\
Jim Lampley\n\
Larry Merchant\n\
Max Kellerman\n\
James Binns\n\
Johnnie Hobbs Jr.\n\
Barney Fitzpatrick\n\
Brian Kenny\n\
Dana Jacobson\n\
Skip Bayless\n\
Charles Johnson\n\
Matt Frack\n\
Woody Paige\n\
Jay Crawford\n\
Lahmard J. Tate\n\
LeRoy Neiman\n\
Mike Tyson' + _(' as ') + 'Himself\n\
Lou DiBella\n\
Joe Cortez\n\
Ricky Cavazos',
			'country'			: 'USA',
			'genre'				: 'Action, Drama, Sportfilm',
			'classification'	: False,
			'studio'			: 'Metro-Goldwyn-Mayer (MGM)',
			'o_site'			: False,
			'site'				: 'http://www.ofdb.de/film/103013,Rocky%20Balboa',
			'trailer'			: False,
			'year'				: 2006,
			'notes'				: False,
			'runtime'			: 102,
			'image'				: True,
			'rating'			: 8
		},
		'film/22489,Ein-Gl%C3%BCckliches-Jahr' : { 
			'title' 			: 'Glückliches Jahr, Ein',
			'o_title' 			: 'Bonne année, La',
			'director'			: 'Claude Lelouch',
			'plot' 				: False,
			'cast'				: 'Lino Ventura\n\
Françoise Fabian\n\
Charles Gérard\n\
André Falcon as Le bijoutier\n\
Mireille Mathieu\n\
Lilo\n\
Claude Mann\n\
Frédéric de Pasquale\n\
Gérard Sire\n\
Silvano Tranquilli\n\
André Barello\n\
Michel Bertay\n\
Norman de la Chesnaye\n\
Pierre Edeline\n\
Pierre Pontiche\n\
Michou\n\
Bettina Rheims\n\
Joseph Rythmann\n\
Georges Staquet\n\
Jacques Villedieu\n\
Harry Walter\n\
Elie Chouraqui',
			'country'			: 'Frankreich',
			'genre'				: 'Komödie, Krimi',
			'classification'	: False,
			'studio'			: 'Les Films 13',
			'o_site'			: False,
			'site'				: 'http://www.ofdb.de/film/22489,Ein-Gl%C3%BCckliches-Jahr',
			'trailer'			: False,
			'year'				: 1973,
			'notes'				: False,
			'runtime'			: 90,
			'image'				: True,
			'rating'			: 6
		},
		'film/54088,Arahan' : { 
			'title' 			: 'Arahan',
			'o_title' 			: 'Arahan jangpung daejakjeon',
			'director'			: 'Ryoo Seung-wan',
			'plot' 				: True,
			'cast'				: 'Ryoo Seung-beom\n\
Yoon Soy' + _(' as ') + 'Wi-jin\n\
Ahn Sung-kee' + _(' as ') + 'Ja-woon\n\
Jung Doo-hong' + _(' as ') + 'Heuk-Woon\n\
Yun Ju-sang\n\
Kim Ji-yeong\n\
Baek Chan-gi\n\
Kim Jae-man\n\
Lee Dae-yeon\n\
Kim Dong-ju\n\
Kim Su-hyeon\n\
Geum Dong-hyeon\n\
Lee Jae-goo\n\
Ahn Kil-kang\n\
Bong Tae-gyu\n\
Im Ha-ryong\n\
Yoon Do-hyeon\n\
Lee Choon-yeon',
			'country'			: 'Südkorea',
			'genre'				: 'Action, Fantasy, Komödie',
			'classification'	: '16',
			'studio'			: 'Fun and Happiness',
			'o_site'			: False,
			'site'				: 'http://www.ofdb.de/film/54088,Arahan',
			'trailer'			: False,
			'year'				: 2004,
			'notes'				: False,
			'runtime'			: 114,
			'image'				: True,
			'rating'			: 7
		}
	}



from sqlalchemy.util import ScopedRegistry
from sqlalchemy.orm.mapper import MapperExtension

__all__ = ['SessionContext', 'SessionContextExt']

class SessionContext(object):
    """A simple wrapper for ``ScopedRegistry`` that provides a
    `current` property which can be used to get, set, or remove the
    session in the current scope.

    By default this object provides thread-local scoping, which is the
    default scope provided by sqlalchemy.util.ScopedRegistry.

    Usage::

      engine = create_engine(...)
      def session_factory():
          return Session(bind_to=engine)
      context = SessionContext(session_factory)

      s = context.current # get thread-local session
      context.current = Session(bind_to=other_engine) # set current session
      del context.current # discard the thread-local session (a new one will
                          # be created on the next call to context.current)
    """

    def __init__(self, session_factory, scopefunc=None):
        self.registry = ScopedRegistry(session_factory, scopefunc)
        super(SessionContext, self).__init__()

    def get_current(self):
        return self.registry()

    def set_current(self, session):
        self.registry.set(session)

    def del_current(self):
        self.registry.clear()

    current = property(get_current, set_current, del_current,
                       """Property used to get/set/del the session in the current scope.""")

    def _get_mapper_extension(self):
        try:
            return self._extension
        except AttributeError:
            self._extension = ext = SessionContextExt(self)
            return ext

    mapper_extension = property(_get_mapper_extension,
                                doc="""Get a mapper extension that implements `get_session` using this context.""")


class SessionContextExt(MapperExtension):
    """A mapper extension that provides sessions to a mapper using ``SessionContext``."""

    def __init__(self, context):
        MapperExtension.__init__(self)
        self.context = context

    def get_session(self):
        return self.context.current



# -*- coding: UTF-8 -*-

__revision__ = '$Id: quick_filter.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils

def change_filter(self):
	x = 0
	text = gutils.gescape(self.widgets['filter']['text'].get_text().decode('utf-8'))
	
	from sqlalchemy import select
	statement = select(self.db.Movie.c)
	
	if text:
		criteria = self.search_criteria[self.widgets['filter']['criteria'].get_active()]
		if criteria in ('year', 'runtime', 'media_num', 'rating'):
			statement.append_whereclause(self.db.Movie.c[criteria]==text)
		else:
			statement.append_whereclause(self.db.Movie.c[criteria].like('%'+text+'%'))
	if self.widgets['filter']['text'].is_focus():
		if len(text)<4: # filter mode
			limit = int(self.config.get('limit', 0, section='mainlist'))
			if limit > 0:
				statement.limit = limit
	self.populate_treeview(statement)

def clear_filter(self):
	# prevent multiple treeview updates
	self.initialized = False
	self.widgets['filter']['text'].set_text('')
	self.widgets['filter']['criteria'].set_active(0)
	self.widgets['filter']['collection'].set_active(0)
	self.widgets['filter']['volume'].set_active(0)
	self.widgets['filter']['tag'].set_active(0)
	self.initialized = True
	self.populate_treeview()

